@@ -36,8 +36,8 @@
 #include "Zcode.h"
 #include "Zmass.h"
       
-c    &&&&&&&&&&&&&&
-c
+!    &&&&&&&&&&&&&&
+!
 
       integer irsave(2)
       logical dodpm
@@ -45,21 +45,21 @@ c
       integer   IDP, NTMASS, NTCHAR, NPMASS, NPCHAR
       common /dpmjetcom/ ELAB, IDP, NTMASS, NTCHAR, NPMASS,NPCHAR
      *  ,irsave, dodpm
-c    &&&&&&&&&&&
-c
-      record /ptcl/ pj  ! input. projectile particle
+!    &&&&&&&&&&&
+!
+      type(ptcl):: pj  ! input. projectile particle
       integer ia     ! input. nucleon number of the target
       integer iz     ! input. charge no. of target
-      record /ptcl/ a(*)  !  output. produced ptcls.  in cms.
+      type(ptcl):: a(*)  !  output. produced ptcls.  in cms.
       integer ntp   ! number of produced ptcls
-c
+!
 
       integer icon,  loopc, econloopc
       
       integer KKMAT
-c///////////
+!///////////
       integer i
-c/////////
+!/////////
 
       integer  NEVENT, ICASCA
       COMMON /DTEVNO/ NEVENT,ICASCA
@@ -75,106 +75,107 @@ c/////////
       save 
 
 #if defined (BREAKUPINFO)
-c            use this when you want to get heavy ion breakup info.
-c            at the first collision. (also put it in ephook --> epiev
-c            to make firstcollision=0
+!            use this when you want to get heavy ion breakup info.
+!            at the first collision. (also put it in ephook --> epiev
+!            to make firstcollision=0
       integer firstcollision
       common /checkglaub/  firstcollision
 #endif
-c///////////////
-c////////////
-c      logical deb
-c      common /cdebug/ deb
-c////////////
+!///////////////
+!////////////
+!      logical deb
+!      common /cdebug/ deb
+!////////////
 
       if(first) then
          NEVENT = 0
-c         ELAB = 3.0d0   
-c         KKMAT = -1
-c         call DT_KKINC(
-c     *   1, 1, ia, iz,  1, ELAB, KKMAT, icon)
+!         ELAB = 3.0d0   
+!         KKMAT = -1
+!         call DT_KKINC(
+!     *   1, 1, ia, iz,  1, ELAB, KKMAT, icon)
       endif
 
       KKMAT = -1
-c      KKMAT = 1
+!      KKMAT = 1
       NEVENT = NEVENT + 1 
 
       cdiff = cdiff0  ! 3% relative error in Econsv. ok
       diffmin = 1.d20
       NTMASS = ia            
       NTCHAR = iz
-      ELAB = pj.fm.p(4)
-      if(pj.code .eq. kgnuc) then
-         ELAB = ELAB/pj.subcode
+      ELAB = pj%fm%p(4)
+      if(pj%code .eq. kgnuc) then
+         ELAB = ELAB/pj%subcode
       endif
       call ccos2dpjidp( pj, IDP, NPMASS, NPCHAR )
       dodpm = .false.
+
       if( IDP .eq. 0) then
-c            dpm cannot treat this         
-         if(pj.fm.p(4) .gt. 9.) then
-            if(pj.code .eq. kkaon .and. LundPara(5) .ne. 0) then  ! not come now
+!            dpm cannot treat this         
+         if(pj%fm%p(4) .gt. 9.) then
+            if(pj%code .eq. kkaon .and. LundPara(5) .ne. 0) then  ! not come now
                call chAcolAdhoc(pj, ia, iz, a, ntp)
-            elseif(pj.code .eq. keta) then  ! not come now
+            elseif(pj%code .eq. keta) then  ! not come now
                call chAcolAdhoc(pj, ia, iz, a, ntp)
             else
                call chAcolAdhoc(pj, ia, iz, a, ntp)    !  gzai,sigma 
-ccc               call chANewLund(pj, ia, iz, a, ntp)
+!cc               call chANewLund(pj, ia, iz, a, ntp)
             endif
          else
             ActiveMdl ='byenergy'
-c                 use fritiof 1.6 or nucrin
+!                 use fritiof 1.6 or nucrin
             call chALund(pj, ia, iz, a, ntp)
          endif
       else
 
-         if(pj.code .eq. knuc .and.
-     *      pj.subcode .ne. antip ) then
-            dodpm = pj.fm.p(4) .gt. 1.6
-         elseif(pj.code .eq. knuc .and. 
-     *      pj.subcode .eq. antip ) then
-c               for light element, 0.97 is o.k for PB
-c               safe to use a higher value.
-            dodpm = pj.fm.p(4) .ge. 0.99
+         if(pj%code .eq. knuc .and.
+     *      pj%subcode .ne. antip ) then
+            dodpm = pj%fm%p(4) .gt. 1.6
+         elseif(pj%code .eq. knuc .and. 
+     *      pj%subcode .eq. antip ) then
+!               for light element, 0.97 is o.k for PB
+!               safe to use a higher value.
+            dodpm = pj%fm%p(4) .ge. 0.99
          else
-            if(pj.code .ne. kgnuc) then
-c         
-               if(pj.code .ne. kkaon .or. pj.charge .ne. 0) then
-                  dodpm = pj.fm.p(4)  .gt. pj.mass + 0.6
-c                      next 8 lies added in v.7.37 Oct25/2008
-                  if(pj.code .eq. kpion .and. pj.charge .eq. -1
+            if(pj%code .ne. kgnuc) then
+!         
+               if(pj%code .ne. kkaon .or. pj%charge .ne. 0) then
+                  dodpm = pj%fm%p(4)  .gt. pj%mass + 0.6
+!                      next 8 lies added in v.7.37 Oct25/2008
+                  if(pj%code .eq. kpion .and. pj%charge .eq. -1
      *               .and. ia .eq. 1 ) then
-                     dodpm = pj.fm.p(4)  .gt. 1.03
-                  elseif( pj.code .eq. klambda .and. 
-     *              pj.subcode .eq. antip 
+                     dodpm = pj%fm%p(4)  .gt. 1.03
+                  elseif( pj%code .eq. klambda .and. 
+     *              pj%subcode .eq. antip 
      *              .and.  ELAB .lt. 4.0 .and. ia .eq. 1 ) then
                      dodpm = .false.
                   endif
-               elseif(pj.subcode .ne. antip) then
-                  dodpm  = pj.fm.p(4) .gt. 1.5
+               elseif(pj%subcode .ne. antip) then
+                  dodpm  = pj%fm%p(4) .gt. 1.5
                endif
             else
-c                 dpmjet cannot treat heavy int. below 5 GeV
+!                 dpmjet cannot treat heavy int. below 5 GeV
               dodpm = ELAB .gt. 5.1
            endif
          endif
-c           endif here       is moved to the last
+!           endif here       is moved to the last
          if(dodpm) then
             icon = 1
             loopc = 0 
             econ =1
             econloopc = 0 
             do while( econ .ne. 0)
-c                 dpm; GeV/n
+!                 dpm; GeV/n
                do while (icon .ne. 0)
-c&&&&&
-c            call rnd1s(irsave)
-c &&&&&
+!&&&&&
+!            call rnd1s(irsave)
+! &&&&&
                   call DT_KKINC(
-     *              NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,ELAB,KKMAT,icon)
+     *                 NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,ELAB,KKMAT,icon)
 !               !!!!!!!! 2013.Apr.19
                   if( dpmEmergencyFlag == 1 ) then
                    ! should happen if proj = pi- and target is p
-                     if( pj.code /= kpion .or. pj.charge /= -1) then
+                     if( pj%code /= kpion .or. pj%charge /= -1) then
                         ! stragne
                         write(0, *)
      *                   ' ****warning:',
@@ -182,7 +183,7 @@ c &&&&&
                         icon = 1
                      else
                          ! make charge +
-!                        pj.charge = 1
+!                        pj%charge = 1
 !                        call ccos2dpjidp( pj, IDP, NPMASS, NPCHAR )
 !                         NPCHAR is not pion charge 
 !                         IDP=14 is pi- and IDP=13 is pi+-
@@ -191,22 +192,22 @@ c &&&&&
                      endif
                      dpmEmergencyFlag = 0
                   elseif(icon .ne. 0) then
-c                   once the event is rejected, even if different
-c                   random number cannot get rid of this loop. 
-c                   so we change the energy by 1 %
+!                   once the event is rejected, even if different
+!                   random number cannot get rid of this loop. 
+!                   so we change the energy by 1 %
                      ELAB=ELAB*1.01   
                      loopc = loopc + 1
-c                  if(loopc .gt. 100) then    ! probably useless.
+!                  if(loopc .gt. 100) then    ! probably useless.
                      if(loopc .gt.  20) then
                         write(ErrorOut,*)
-     *                       ' pj code, subcode, charge=',pj.code,
-     *                       pj.subcode, pj.charge, ' E=',pj.fm.p(4),
+     *                       ' pj code, subcode, charge=',pj%code,
+     *                       pj%subcode, pj%charge, ' E=',pj%fm%p(4),
      *                       ' Target A=', ia, ' Z=', iz,
      *                       ' loopc=',loopc
                         call cpdpmjetinp
                         call cerrorMsg(
      *                        'dpmjet3 too many loop in cdpmjet',1)     
-c                            no ptcl produced
+!                            no ptcl produced
                         call cdpmNoPtcl
                         icon = 0
                         econ = 0
@@ -222,36 +223,37 @@ c                            no ptcl produced
                       first = .false. 
                    endif
                 enddo
-                if(econ .ne. 0) then
-!                                 ia added Nov.9,2013
-                  call csetdpmresul(pj, ia, a, ntp,
-     *             sumTE, sumKE, sumRareTE, sumRareKE, krarec,
-     *             dpmRareDecay)
-                  Ein = NTMASS*masp + pj.fm.p(4)
+
+                if(econ .ne. 0) then  ! first time econ /= 0
+                   call csetdpmresul(pj, ia, a, ntp,
+     *               sumTE, sumKE, sumRareTE, sumRareKE, krarec,
+     *               dpmRareDecay)
+
+                  Ein = NTMASS*masp + pj%fm%p(4)
                   dErel = sumTE/Ein -1.
-c////////////////
-c                  if(firstcollision==0)then
-c                     write(0,*) 
-c     *                    ' dErel=',dErel, ' sumTE=',sumTE, ' Ein=',Ein
-c                  endif
-c////////////
+!////////////////
+!                  if(firstcollision==0)then
+!                     write(0,*) 
+!     *                    ' dErel=',dErel, ' sumTE=',sumTE, ' Ein=',Ein
+!                  endif
+!////////////
                   if( abs(dErel) .lt. abs(diffmin)) then
                      diffmin = dErel
                   endif
 
                   if(abs(dErel) .gt. cdiff) then
-c  
+!  
                      econloopc = econloopc +1
                      if(econloopc .gt. 10 
      *                  .and. cdiff .ne. cdiff0 ) then
                         write(0,*) 'EinT=',Ein, ' EoutT=',sumTE
-                        write(0, *)'EinK=', pj.fm.p(4)-pj.mass
+                        write(0, *)'EinK=', pj%fm%p(4)-pj%mass
                         write(0,*) 'EoutK=', sumKE
                         write(0,*) 'rare p=',krarec
                         write(0,*) 'RareTE=', sumRareTE,' KE=',sumRareKE
                         write(ErrorOut,*) ' dpmjet3 Econsv difficult ',
-     *                       ' proj code, subcode, charge=',pj.code,
-     *                       pj.subcode, pj.charge, ' E=',pj.fm.p(4),
+     *                       ' proj code, subcode, charge=',pj%code,
+     *                       pj%subcode, pj%charge, ' E=',pj%fm%p(4),
      *                       ' Target A=', ia, ' Z=', iz,
      *                       ' min Rel dE=',  dErel,
      *                       ' loopc=',econloopc
@@ -269,53 +271,53 @@ c
                endif
             enddo
          else
-            if(pj.code .le. knuc) then
-c               use fritiof 1.6 or nucrin
+            if(pj%code .le. knuc) then
+!               use fritiof 1.6 or nucrin
                ActiveMdl = 'byenergy'
                call chALund(pj, ia, iz, a, ntp)
-            elseif(pj.code .eq. kgnuc) then
-c  
+            elseif(pj%code .eq. kgnuc) then
+!  
                call cerrorMsg('Recursive call of heavy routine',0)
-c                    dpmjet is bypaseed for heavy < 5GeV
-c               if(ELAB .gt. 0.5) then
-c                  ActiveMdl = 'byenergy'
-c                  call cheavyInt(pj, ia, iz, a, ntp)
-c               else
-c                  a(1) = pj
-c                  ntp = 1
-c               endif
+!                    dpmjet is bypaseed for heavy < 5GeV
+!               if(ELAB .gt. 0.5) then
+!                  ActiveMdl = 'byenergy'
+!                  call cheavyInt(pj, ia, iz, a, ntp)
+!               else
+!                  a(1) = pj
+!                  ntp = 1
+!               endif
             else
-c                  neglect this interaction
+!                  neglect this interaction
                ntp = 0
             endif
          endif
       endif
-c/////////////////////
+!/////////////////////
       do i = 1, ntp
-         if(a(i).code .eq. kphoton .and.  a(i).charge .ne.  0) then
+         if(a(i)%code .eq. kphoton .and.  a(i)%charge .ne.  0) then
             write(0,*)
-     *       'dpmerr  photon charge=' ,a(i).charge, ' subc=',
-     *       a(i).subcode, ' E=',a(i).fm.p(4)
+     *       'dpmerr  photon charge=' ,a(i)%charge, ' subc=',
+     *       a(i)%subcode, ' E=',a(i)%fm%p(4)
             write(0,*)
-     *      'dpmerr dodpm=',dodpm,' ntp=', ntp, ' pj=', pj.code,
-     *       ' pj.charge=', pj.charge, ' ia=',ia, ' iz=', iz
+     *      'dpmerr dodpm=',dodpm,' ntp=', ntp, ' pj=', pj%code,
+     *       ' pj%charge=', pj%charge, ' ia=',ia, ' iz=', iz
          endif
       enddo
-c/////////////////
+!/////////////////
 
       end
       subroutine cpdpmjetinp
       implicit none
-c            print current dpmjet input
+!            print current dpmjet input
       character*100 msg
-c    &&&&&&&&&&&&&&
+!    &&&&&&&&&&&&&&
       integer irsave(2)
       logical dodpm
       real*8    ELAB
       integer   IDP, NTMASS, NTCHAR, NPMASS, NPCHAR
       common /dpmjetcom/ ELAB, IDP, NTMASS, NTCHAR, NPMASS,NPCHAR
      *   ,irsave, dodpm
-c    &&&&&&&&&&&
+!    &&&&&&&&&&&
       character*16 model
       call cqActiveMdl(model)
       write(msg, *) ' dodpm=',dodpm, ' activemodel=', model
@@ -325,7 +327,7 @@ c    &&&&&&&&&&&
       write(msg, *) ' target: A=', NTMASS, ' Z=',NTCHAR,
      *   ' NPA=',NPMASS, ' NPZ=',NPCHAR
       call cerrorMsg(msg, 1)
-c
+!
       write(msg, *) ' ir=', irsave
       call cerrorMsg(msg, 1)
       end
@@ -335,9 +337,9 @@ c
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
 #include "Zcode.h"
 #include "Zptcl.h"
-      record /ptcl/ pj    ! input. projectile 
+      type(ptcl):: pj    ! input. projectile 
       integer,intent(in)::tgA ! input. target A  added Nov.9,2013
-      record /ptcl/ a(*)  ! output.  
+      type(ptcl):: a(*)  ! output.  
       integer ntp  ! ouptut. number of ptcls put in a
       real*8  sumTE  ! output. produced ptcls' total energy 
       real*8  sumKE  ! //                      kinetic
@@ -346,57 +348,57 @@ c
       integer krarec ! output rare particle counter
       integer,intent(in):: dpmRareDecay ! how to control rare 
                                       ! ptcls
-* COMMON /DTEVT1/ :
-*                   NHKK         number of entries in common block
-*                   NEVHKK       number of the event
-*                   ISTHKK(i)    status code for entry i
-*                   IDHKK(i)     identifier for the entry
-*                                (for particles: identifier according
-*                                 to the PDG numbering scheme)
-*                   JMOHKK(1,i)  pointer to the entry of the first mother
-*                                of entry i
-*                   JMOHKK(2,i)  pointer to the entry of the second mother
-*                                of entry i
-*                   JDAHKK(1,i)  pointer to the entry of the first daughter
-*                                of entry i
-*                   JDAHKK(2,i)  pointer to the entry of the second daughter
-*                                of entry i
-*                   PHKK(1..3,i) 3-momentum
-*                   PHKK(4,i)    energy
-*                   PHKK(5,i)    mass
-*
+! COMMON /DTEVT1/ :
+!                   NHKK         number of entries in common block
+!                   NEVHKK       number of the event
+!                   ISTHKK(i)    status code for entry i
+!                   IDHKK(i)     identifier for the entry
+!                                (for particles: identifier according
+!                                 to the PDG numbering scheme)
+!                   JMOHKK(1,i)  pointer to the entry of the first mother
+!                                of entry i
+!                   JMOHKK(2,i)  pointer to the entry of the second mother
+!                                of entry i
+!                   JDAHKK(1,i)  pointer to the entry of the first daughter
+!                                of entry i
+!                   JDAHKK(2,i)  pointer to the entry of the second daughter
+!                                of entry i
+!                   PHKK(1..3,i) 3-momentum
+!                   PHKK(4,i)    energy
+!                   PHKK(5,i)    mass
+!
 
-*  The final state particles from the actual event (number NEVHKK)
-*  can be found in DTEVT1 and identified by their status:
-*
-*     ISTHKK(i) = 1    final state particle produced in
-*                      photon-/hadron-/nucleon-nucleon collisions or
-*                      in intranuclear cascade processes
-*                -1    nucleons, deuterons, H-3, He-3, He-4 evaporated
-*                      from excited nucleus and
-*                      photons produced in nuclear deexcitation processes
-*                1001  residual nucleus (ground state)
-*
-*  The types of these particles/nuclei are given in IDHKK as follows
-*
-*     all final state part. except nuclei :
-*       IDHKK(i)=particle identifier according to PDG numbering scheme
-*     nuclei (evaporation products, and residual nucleus) :
-*       IDHKK(i)=80000, IDRES(i)=mass number, IDXRES(i)=charge number
-*
-*  The 4-momenta and masses can be found in PHKK (target nucleus rest frame):
-*                   PHKK(1..3,i) 3-momentum (p_x,p_y,p_z)
-*                   PHKK(4,i)    energy
-*                   PHKK(5,i)    mass
-*
-*
+!  The final state particles from the actual event (number NEVHKK)
+!  can be found in DTEVT1 and identified by their status:
+!
+!     ISTHKK(i) = 1    final state particle produced in
+!                      photon-/hadron-/nucleon-nucleon collisions or
+!                      in intranuclear cascade processes
+!                -1    nucleons, deuterons, H-3, He-3, He-4 evaporated
+!                      from excited nucleus and
+!                      photons produced in nuclear deexcitation processes
+!                1001  residual nucleus (ground state)
+!
+!  The types of these particles/nuclei are given in IDHKK as follows
+!
+!     all final state part. except nuclei :
+!       IDHKK(i)=particle identifier according to PDG numbering scheme
+!     nuclei (evaporation products, and residual nucleus) :
+!       IDHKK(i)=80000, IDRES(i)=mass number, IDXRES(i)=charge number
+!
+!  The 4-momenta and masses can be found in PHKK (target nucleus rest frame):
+!                   PHKK(1..3,i) 3-momentum (p_x,p_y,p_z)
+!                   PHKK(4,i)    energy
+!                   PHKK(5,i)    mass
+!
+!
       PARAMETER (NMXHKK=90000)
 
       COMMON /DTEVT1/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK),
      &                JMOHKK(2,NMXHKK),JDAHKK(2,NMXHKK),
      &                PHKK(5,NMXHKK),VHKK(4,NMXHKK),WHKK(4,NMXHKK)
 
-* extended event history
+! extended event history
       COMMON /DTEVT2/ IDRES(NMXHKK),IDXRES(NMXHKK),NOBAM(NMXHKK),
      &                IDBAM(NMXHKK),IDCH(NMXHKK),NPOINT(10),
      &                IHIST(2,NMXHKK)
@@ -419,10 +421,10 @@ c
       real(8):: thresh   ! pjKEn*0.5. if KE/n of evaporation > this
                    ! it should be from projectile 
 #endif
-c      if(NHKK .gt. 1000 ) then
-c         write(0,*) ' NHKK=',NHKK
-c      endif
-c///////////////
+!      if(NHKK .gt. 1000 ) then
+!         write(0,*) ' NHKK=',NHKK
+!      endif
+!///////////////
       ntp =0
       sumKE = 0.
       sumTE = 0.
@@ -437,9 +439,9 @@ c///////////////
       neHTc  = 0  ! evaporated heavyies from target 
       nrPc  = 0  ! remnant  heavies from projectile
       nrTc  = 0 ! remnant  heavies from target 
-      pjKEn = pj.fm.p(4) + pj.mass
-      if(pj.code == kgnuc ) then
-         pjKEn = pjKEn/pj.subcode
+      pjKEn = pj%fm%p(4) + pj%mass
+      if(pj%code == kgnuc ) then
+         pjKEn = pjKEn/pj%subcode
       endif
       thresh = pjKEn*0.5
 #endif
@@ -496,34 +498,34 @@ c///////////////
             if(code .ne. krare) then
                ntp = ntp +1
                call cmkptc(code, subcode, charge, a(ntp))
-               a(ntp).fm.p(1) = PHKK(1,i)
-               a(ntp).fm.p(2) = PHKK(2,i)
-               a(ntp).fm.p(3) = PHKK(3,i)
-               a(ntp).fm.p(4) = PHKK(4,i)
+               a(ntp)%fm%p(1) = PHKK(1,i)
+               a(ntp)%fm%p(2) = PHKK(2,i)
+               a(ntp)%fm%p(3) = PHKK(3,i)
+               a(ntp)%fm%p(4) = PHKK(4,i)
                if( code == kgnuc)  then
-                  a(ntp).mass =  PHKK(5,i)
+                  a(ntp)%mass =  PHKK(5,i)
                endif
             else
                krarec = krarec + 1 
                sumRareKE = sumRareKE +  (PHKK(4,i) - PHKK(5,i))
                sumRareTE = sumRareTE +  PHKK(4,i) 
             endif
-c            write(*,*)
-c     *      IDHKK(i), code, subcode, charge,
-c     *      sngl(PHKK(4,i)),
-c     *      sngl(PHKK(1,i)),sngl(PHKK(2,i)),sngl(PHKK(3,i))
+!            write(*,*)
+!     *      IDHKK(i), code, subcode, charge,
+!     *      sngl(PHKK(4,i)),
+!     *      sngl(PHKK(1,i)),sngl(PHKK(2,i)),sngl(PHKK(3,i))
          ELSEIF (ABS(ISTHKK(i)).EQ.1001) THEN
-c             residual nucleus;
+!             residual nucleus;
             charge = IDXRES(i)
             code = kgnuc
             subcode = IDRES(i)
             ntp = ntp +1
             call cmkptc(code, subcode, charge, a(ntp))
-            a(ntp).mass =  PHKK(5,i)
-            a(ntp).fm.p(1) = PHKK(1,i)
-            a(ntp).fm.p(2) = PHKK(2,i)
-            a(ntp).fm.p(3) = PHKK(3,i)
-            a(ntp).fm.p(4) = PHKK(4,i)
+            a(ntp)%mass =  PHKK(5,i)
+            a(ntp)%fm%p(1) = PHKK(1,i)
+            a(ntp)%fm%p(2) = PHKK(2,i)
+            a(ntp)%fm%p(3) = PHKK(3,i)
+            a(ntp)%fm%p(4) = PHKK(4,i)
             sumKE = sumKE + (PHKK(4,i) - PHKK(5,i))
             sumTE = sumTE + PHKK(4,i)
 #if defined (BREAKUPINFO)
@@ -539,15 +541,15 @@ c             residual nucleus;
      *          id, code, subcode,charge,
      *          ' KE/n=', (PHKK(4,i) - PHKK(5,i))/subcode, ISTHKK(i)
             endif
-c            write(0,*) ' p=',PHKK(1,i), PHKK(2,i), PHKK(3,i),PHKK(4,i)
+!            write(0,*) ' p=',PHKK(1,i), PHKK(2,i), PHKK(3,i),PHKK(4,i)
 #endif
          ENDIF
       enddo
 !        aritificial symmetry recovering   
       call cASRforDPM(pj, tgA, a, ntp)
 
-c     -------------- rotate
       call crot3mom(pj, a, ntp)
+      
 #if defined (BREAKUPINFO)
       firstcollision = 1
       id = "No"
@@ -561,11 +563,11 @@ c     -------------- rotate
 #include "Zcode.h"
 #include "Zptcl.h"
 #include "Ztrackp.h"
-      record /ptcl/ pj  ! input.  projectile particle
+      type(ptcl):: pj  ! input.  projectile particle
       integer,intent(in):: tgA ! input Target A
       integer,intent(in):: ntp  ! # of produced particles
                                 ! in a
-      record /ptcl/ a(ntp)  ! in/out. 
+      type(ptcl):: a(ntp)  ! in/out. 
 
 
       
@@ -573,18 +575,20 @@ c     -------------- rotate
       real(8),parameter::maxPz=2.0 ! GeV/c
       real(8):: cosf, sinf, pt, u
       integer:: i, j
-      record /ptcl/ proton, b 
+      type(ptcl):: proton, b 
       
       if( ASRforDPM == "no") return !!!!!!
-      if( ( pj.code /= kgnuc  .or. pj.subcode < minA )
-     *     .and. tgA < minA )  return !!!!!!!!!!
 !       both target and progjectile is non heavy (< minA)
-!       nothing to do
+!     nothing to do
+!     if( ( pj.code /= kgnuc  .or. pj.subcode < minA )
+!           *     .and. tgA < minA )  return !!!!!!!!!!
+!       changed to (2016. Jun. )
+      if ( tgA < minA )  return !!!!!!!!!!    
       if( ASRforDPM == "m" ) then
 !          reverse the sign of Px with 1/2 prob.
          call rndc(u)
          if(u < 0.5) then 
-            a(:).fm.p(1) = - a(:).fm.p(1)
+            a(:)%fm%p(1) = - a(:)%fm%p(1)
          endif
       elseif( ASRforDPM(1:1) == "r" )  then
            ! now r or r1. This business may better done in CMS
@@ -592,37 +596,37 @@ c     -------------- rotate
          if(  tgA >= minA ) then
             ! target backscater region both for r and r1
             do i = 1, ntp
-               if( a(i).code == kpion .or.
-     *              a(i).code == kkaon  ) then
-                  if(  a(i).fm.p(3) < maxPz ) then
-                     pt = sqrt( a(i).fm.p(1)**2 +a(i).fm.p(2)**2 )
+               if( a(i)%code == kpion .or.
+     *              a(i)%code == kkaon  ) then
+                  if(  a(i)%fm%p(3) < maxPz ) then
+                     pt = sqrt( a(i)%fm%p(1)**2 +a(i)%fm%p(2)**2 )
                      call kcossn(cosf, sinf)
-                     a(i).fm.p(1)= pt*cosf
-                     a(i).fm.p(2)= pt*sinf
+                     a(i)%fm%p(1)= pt*cosf
+                     a(i)%fm%p(2)= pt*sinf
                   endif
                endif
             enddo
          endif
          if( ASRforDPM /= "r1" .and.
-     *       pj.code == kgnuc .and. pj.subcode >= minA) then
-!                proj. very forward region. see it at pj.rest
+     *       pj%code == kgnuc .and. pj%subcode >= minA) then
+!                proj. very forward region. see it at pj%rest
 !                system.
             j = 0
             do i = 1, ntp
                j = j + 1
                if( j == 1 ) then
                   call cmkptc(knuc, -1, 1, proton)
-                  proton.fm.p(1:3) = pj.fm.p(1:3)/pj.subcode
-                  proton.fm.p(4) =
-     *             sqrt( sum(proton.fm.p(1:3)**2+proton.mass**2))
+                  proton%fm%p(1:3) = pj%fm%p(1:3)/pj%subcode
+                  proton%fm%p(4) =
+     *             sqrt( sum(proton%fm%p(1:3)**2+proton%mass**2))
                endif         
                     ! boost to pj /n  rest frame
                call cbst1(j, proton, a(i), b)
-               if(  b.fm.p(3) > - maxPz ) then
-                  pt = sqrt( a(i).fm.p(1)**2 +a(i).fm.p(2)**2 )
+               if(  b%fm%p(3) > - maxPz ) then
+                  pt = sqrt( a(i)%fm%p(1)**2 +a(i)%fm%p(2)**2 )
                   call kcossn(cosf, sinf)
-                  a(i).fm.p(1)= pt*cosf
-                  a(i).fm.p(2)= pt*sinf
+                  a(i)%fm%p(1)= pt*cosf
+                  a(i)%fm%p(2)= pt*sinf
                endif
             enddo
          endif
@@ -633,10 +637,10 @@ c     -------------- rotate
       end  subroutine cASRforDPM
 
       subroutine cdpmNoPtcl
-c         clear no. of produced partilce
+!         clear no. of produced partilce
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
-*
-*
+!
+!
       PARAMETER (NMXHKK=90000)
 
       COMMON /DTEVT1/ NHKK,NEVHKK,ISTHKK(NMXHKK),IDHKK(NMXHKK),
@@ -653,43 +657,43 @@ c         clear no. of produced partilce
       end
 
 
-c      IDP number
-c     'PROTON  ' , 'APROTON ' , 'ELECTRON' , 'POSITRON' ,
-c        1            2            3             4  
-c     'NEUTRIE ' , 'ANEUTRIE' , 'PHOTON  ' , 'NEUTRON ' , 'ANEUTRON' ,
-c        5             6           7             8             9
-c     &'MUON+   ' , 'MUON-   ' , 'KAONLONG' , 'PION+   ' , 'PION-   ' ,
-c       10             11          12           13           14
-c     &'KAON+   ' , 'KAON-   ' , 'LAMBDA  ' , 'ALAMBDA ' , 'KAONSHRT' ,
-c       15            16           17           18           19
-c     &'SIGMA-  ' , 'SIGMA+  ' , 'SIGMAZER' , 'PIZERO  ' , 'KAONZERO' ,
-c       20            21           22           23           24  
-c     &'AKAONZER' , 'NEUTRIM ' , 'ANEUTRIM' , 'NEUTRIT ' , 'ANEUTRIT' ,
-c       25            26           27           28           29 
-c     
+!      IDP number
+!     'PROTON  ' , 'APROTON ' , 'ELECTRON' , 'POSITRON' ,
+!        1            2            3             4  
+!     'NEUTRIE ' , 'ANEUTRIE' , 'PHOTON  ' , 'NEUTRON ' , 'ANEUTRON' ,
+!        5             6           7             8             9
+!     &'MUON+   ' , 'MUON-   ' , 'KAONLONG' , 'PION+   ' , 'PION-   ' ,
+!       10             11          12           13           14
+!     &'KAON+   ' , 'KAON-   ' , 'LAMBDA  ' , 'ALAMBDA ' , 'KAONSHRT' ,
+!       15            16           17           18           19
+!     &'SIGMA-  ' , 'SIGMA+  ' , 'SIGMAZER' , 'PIZERO  ' , 'KAONZERO' ,
+!       20            21           22           23           24  
+!     &'AKAONZER' , 'NEUTRIM ' , 'ANEUTRIM' , 'NEUTRIT ' , 'ANEUTRIT' ,
+!       25            26           27           28           29 
+!     
       subroutine ccos2dpjidp(pj, idp, npmass, npchar)
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
-c          cosmos code to idp in dpmjet
-      record /ptcl/  pj
+!          cosmos code to idp in dpmjet
+      type(ptcl)::  pj
       integer idp  ! output. dpm code. which can be a projectile
       integer npmass ! ouptut.  projectile code (mass) if pj is
                      ! used as a projectile
       integer npchar ! output. charge in the same meaning as above.
 
-      if(pj.code .eq. kgnuc) then
+      if(pj%code .eq. kgnuc) then
          idp = 1
-         npmass = pj.subcode
-         npchar = pj.charge
+         npmass = pj%subcode
+         npchar = pj%charge
       else
          npmass = 1
          npchar = 1
-         if(pj.code .eq. knuc) then
-            if(pj.charge .eq. 1) then
+         if(pj%code .eq. knuc) then
+            if(pj%charge .eq. 1) then
                idp=1
-            elseif(pj.charge .eq. 0) then
-               if(pj.subcode .eq. antip) then
+            elseif(pj%charge .eq. 0) then
+               if(pj%subcode .eq. antip) then
                   idp = 9
                else
                   idp = 8
@@ -697,45 +701,45 @@ c          cosmos code to idp in dpmjet
             else
                idp = 2
             endif
-         elseif( pj.code .eq. kpion) then
-            if(pj.charge .eq. 1) then
+         elseif( pj%code .eq. kpion) then
+            if(pj%charge .eq. 1) then
                idp = 13
-            elseif(pj.charge .eq. -1) then
+            elseif(pj%charge .eq. -1) then
                idp = 14
             else
                idp = 23
             endif
-         elseif( pj.code .eq. kkaon) then
-            if(pj.charge .eq. 1) then
+         elseif( pj%code .eq. kkaon) then
+            if(pj%charge .eq. 1) then
                idp = 15
-            elseif(pj.charge .eq. -1) then
+            elseif(pj%charge .eq. -1) then
                idp = 16
-            elseif(pj.subcode .lt. 0) then
-c                 k0; disregard  short or long but see ptlc or anti
+            elseif(pj%subcode .lt. 0) then
+!                 k0; disregard  short or long but see ptlc or anti
                idp = 24
             else
-c                 k0_bar
-cccc               idp = 25
+!                 k0_bar
+!ccc               idp = 25
                idp = 24   ! tentative setting. k0bar will die easily
             endif
-         elseif(pj.code .eq. klambda) then
-            if(pj.subcode .eq. antip) then
+         elseif(pj%code .eq. klambda) then
+            if(pj%subcode .eq. antip) then
                idp = 18
             else
                idp = 17
             endif
-         elseif(pj.code .eq. kphoton) then
+         elseif(pj%code .eq. kphoton) then
             idp = 7
-         elseif(pj.code .eq. ksigma) then
-            if(pj.charge .eq. 1) then
+         elseif(pj%code .eq. ksigma) then
+            if(pj%charge .eq. 1) then
                idp = 21
-            elseif(pj.charge .eq. -1) then
+            elseif(pj%charge .eq. -1) then
                idp = 20
             else
                idp = 22
             endif
          else
-c              cannot be a projectile
+!              cannot be a projectile
             idp = 0
          endif
       endif
@@ -757,9 +761,9 @@ c              cannot be a projectile
          call cerrorMsg('above file cannot be opened', 0)
       endif
 
-c          init dpm; Thru this call, input data is read via TempDev
-c     Glauber initialization data location is given in that
-c     data and the call to cdpmOpen is made from within dpmjet
+!          init dpm; Thru this call, input data is read via TempDev
+!     Glauber initialization data location is given in that
+!     data and the call to cdpmOpen is made from within dpmjet
       IEMU = 0
       CALL DT_DTUINI(NEVTS,EPN,NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,IEMU)
 
@@ -767,19 +771,19 @@ c     data and the call to cdpmOpen is made from within dpmjet
       end
       subroutine cdpmOpen(io, file)
       implicit none
-c      since dpmjet cannot use long file name, we may encounter
-c      difficulty in dealing with full path which is needed to
-c      specify the files when distributing jobs over a 
-c      number of  workstations.  So I had to make a
-c      correction in the dpmjet program;Say, the open statements
-c      for reading GLAUB-PAR data
+!      since dpmjet cannot use long file name, we may encounter
+!      difficulty in dealing with full path which is needed to
+!      specify the files when distributing jobs over a 
+!      number of  workstations.  So I had to make a
+!      correction in the dpmjet program;Say, the open statements
+!      for reading GLAUB-PAR data
 
-c         OPEN(LLOOK,FILE=CGLB//'.GLB',STATUS='UNKNOWN')
-c         OPEN(LLOOK,FILE=CGLB(1:I-1)//'.GLB',STATUS='UNKNOWN')
-c
-c      are replaced  by 
-c      
-c           call cdpmOpen(LLOOK, CFILE)
+!         OPEN(LLOOK,FILE=CGLB//'.GLB',STATUS='UNKNOWN')
+!         OPEN(LLOOK,FILE=CGLB(1:I-1)//'.GLB',STATUS='UNKNOWN')
+!
+!      are replaced  by 
+!      
+!           call cdpmOpen(LLOOK, CFILE)
       
       integer io  ! input.  file descripter to be opened
       character*12 file  ! input. file name, say, containig glauber
@@ -804,8 +808,8 @@ c           call cdpmOpen(LLOOK, CFILE)
       subroutine cdpmOpen2(io, file)
       implicit none
 #include "Zmanager.h"
-c      This opens a file with Cosmos/Data/DPM as a prefix
-c    
+!      This opens a file with Cosmos/Data/DPM as a prefix
+!    
       integer io  ! input.  file descripter to be opened
       character*(*) file  ! input. file name.
 
@@ -904,3 +908,26 @@ c
          enddo
       endif
       end
+      subroutine cqDpmIntType(inttype)
+      implicit none
+!
+! general process information; only for dpmjet3
+      INTEGER IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON
+      COMMON /POPRCS/ IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON(15,4)
+!      IPROCE
+!             1 non-diffractive inelastic
+!             2 elestic 
+!             3 quasi elestic vector meson prod. (photon)
+!             4 central diffraction
+!             5 single diff. ptcl 1
+!             6 //           ptcl 2
+!             7 double diff. 
+!             8 direct photo-hadron
+! For moore detail, see manual in Documents/CosmicRays/phojetShort.pdf
+!               say, IDIFR1 classifies IPROCE=5
+      
+      integer,intent(out):: inttype
+
+      inttype = IPROCE
+      end
+      
