@@ -1,7 +1,7 @@
       module modEpos
       implicit none
 #include "Zptcl.h"
-      record /ptcl/ cms
+      type(ptcl):: cms
       character*10,save:: from
       end module modEpos
 
@@ -23,12 +23,12 @@
 
       idprojin = 1120
       idtargin = 1120
-c      elab = 200.
+!      elab = 200.
       engy   = -1.
       pnll = 200.
       ekin = -1.
       ecms =  -1.
-c      iframe=12                 ! 12=target frame (needed ?)
+!      iframe=12                 ! 12=target frame (needed ?)
       if( from == 'gencol' ) then
          call cqGencolCMS(cms)
       endif
@@ -59,29 +59,29 @@ c      iframe=12                 ! 12=target frame (needed ?)
 #include "Zcode.h"
 #include "Zptcl.h"
       include "../epos.inc"
-      record /ptcl/ pjin  ! input projectile particle
-      record /ptcl/ tg  ! input target particle in lab.
+      type(ptcl):: pjin  ! input projectile particle
+      type(ptcl):: tg  ! input target particle in lab.
       real(8),intent(out):: sig  ! inelastic cross section in mb
 
-      record /ptcl/pj
+      type(ptcl)::pj
       real(8):: u
 
       pj = pjin
 
-      elab = pj.fm.p(4)
+      elab = pj%fm%p(4)
       engy = -1.
       pnll = -1.
       ekin = -1.
       ecms =  -1.
       iframe=12            ! 12=target frame ; needed ?
 
-      if( pj.code == kgnuc )  then
-         maproj = pj.subcode           !proj A
-         laproj = pj.charge
+      if( pj%code == kgnuc )  then
+         maproj = pj%subcode           !proj A
+         laproj = pj%charge
          idprojin = 1120
-         elab = elab/pj.subcode   ! E(GeV)/n
+         elab = elab/pj%subcode   ! E(GeV)/n
       else
-         if( pj.code == kphoton)  then
+         if( pj%code == kphoton)  then
          !  replace it to pi0 or eta
             call rndc(u)
             if( u < 0.5d0 ) then
@@ -90,8 +90,8 @@ c      iframe=12                 ! 12=target frame (needed ?)
                call cmkptc(keta, 1,  0, pj)
             endif
             ! adjust momentum
-            cf = sqrt(1.d0 - (pj.mass/pj.fm.p(4))**2 )
-            pj.fm.p(1:3) = cf * pj.fm.p(1:3)
+            cf = sqrt(1.d0 - (pj%mass/pj%fm%p(4))**2 )
+            pj%fm%p(1:3) = cf * pj%fm%p(1:3)
          endif   
          call ccos2eposB( pj, idprojin)
                 ! not idporj; before ainit "in"  must be added
@@ -110,27 +110,27 @@ c      iframe=12                 ! 12=target frame (needed ?)
          laproj = -1
          maproj = 1
       endif
-c/////////////
-c      write(0,*) ' idprojin, laproj, maproj= ',
-c     *        idprojin, laproj, maproj
-c      write(0,*) ' idprojin has been changed to', idprojin
-c//////////
+!/////////////
+!      write(0,*) ' idprojin, laproj, maproj= ',
+!     *        idprojin, laproj, maproj
+!      write(0,*) ' idprojin has been changed to', idprojin
+!//////////
 
 
-      if( tg.code == kgnuc ) then
+      if( tg%code == kgnuc ) then
          idtargin = 1120
-         latarg = tg.charge     !targ Z
-         matarg = tg.subcode    !targ A
+         latarg = tg%charge     !targ Z
+         matarg = tg%subcode    !targ A
       else  ! p or n
          call ccos2eposB( tg, idtargin)
          matarg = 1           
          laproj = -1
       endif
-c////////////
-c      write(0,*) ' idtargin, latarg, matarg= ',
-c     *  idtargin, latarg, matarg
-c      write(0,*) ' entering  ainit'
-c/////////////
+!////////////
+!      write(0,*) ' idtargin, latarg, matarg= ',
+!     *  idtargin, latarg, matarg
+!      write(0,*) ' entering  ainit'
+!/////////////
       call ainit
       sig = sigineaa
       end
@@ -139,18 +139,18 @@ c/////////////
       use modEpos
       implicit none
 #include "Zcode.h"
-c #include "Zptcl.h"
+! #include "Zptcl.h"
 
-      record /ptcl/ pj   !  inp. projectile
+      type(ptcl):: pj   !  inp. projectile
       integer,intent(in):: ia  ! target A
       integer,intent(in):: iz  ! target Z
-      record /ptcl/ a(*)  !  generated ptcl. must be >= n
+      type(ptcl):: a(*)  !  generated ptcl. must be >= n
       integer,intent(out):: n  ! # of  ptcls
       
       integer:: i, j
       include "../epos.inc"
       integer code, subcode, charge, kf
-      record /ptcl/ tg
+      type(ptcl):: tg
       real(8):: xs
 
       if( ia > 1 ) then
@@ -158,8 +158,8 @@ c #include "Zptcl.h"
       else
          call cmkptc(knuc, ia, iz, tg)
       endif         
-      tg.fm.p(1:3) = 0.
-      tg.fm.p(4) = tg.mass
+      tg%fm%p(1:3) = 0.
+      tg%fm%p(4) = tg%mass
       call ceposIniOneEvent(pj, tg, xs)
 
 
@@ -184,13 +184,13 @@ c #include "Zptcl.h"
       do i = 1, nhep
          kf = idhep(i)
          call ckf2cos(kf, code, subcode, charge)
-c///////////
-c         write(0,
-c     *  '(i3, a, i10, a, i3, a, i3, a, i4, a, i4, a, 1p,4g13.3)')
-c     *  i, ' idhep=', idhep(i), ' code=',code, 
-c     *  ' status=', isthep(i), ' moth=', jmohep(1,i), ' daug=',
-c     *  jdahep(1,i), ' p(1:4)= ', phep(1:4, i)
-c///////////
+!///////////
+!         write(0,
+!     *  '(i3, a, i10, a, i3, a, i3, a, i4, a, i4, a, 1p,4g13.3)')
+!     *  i, ' idhep=', idhep(i), ' code=',code, 
+!     *  ' status=', isthep(i), ' moth=', jmohep(1,i), ' daug=',
+!     *  jdahep(1,i), ' p(1:4)= ', phep(1:4, i)
+!///////////
          if( isthep(i) /= 4 ) then
             if( code == krare .and. kf >= 1000000020 ) then
 !                 Z= 0 A=subcode;  nucleus
@@ -200,14 +200,14 @@ c///////////
                   write(0,*) ' subcode=',subcode,' charge=',charge
                   write(0,*) ' ia = ', ia, ' iz=',iz
                   write(0,*) ' 4mom=',phep(1:4,i) 
-                  if( pj.code == kgnuc ) then
+                  if( pj%code == kgnuc ) then
                   !  assign charge; not so bad method
                      call csetFragChg(
-     *                    int(pj.subcode), subcode, charge)
+     *                    int(pj%subcode), subcode, charge)
                      code = kgnuc
                      n = n + 1
                      call cmkptc(code, subcode, charge, a(n))
-                     a(n).fm.p(1:4) = phep(1:4,i)
+                     a(n)%fm%p(1:4) = phep(1:4,i)
                      if( phep(4,i)/subcode > phep(5,i)*10 ) then
                         write(0,*) ' accepted as charge=',charge
                         write(0,*) ' nucleus'
@@ -217,9 +217,9 @@ c///////////
             else
                n = n + 1
                call cmkptc(code, subcode, charge, a(n))
-               a(n).fm.p(1:4) = phep(1:4,i)
+               a(n)%fm%p(1:4) = phep(1:4,i)
                !    use mass in phep
-               a(n).mass = phep(5,i)
+               a(n)%mass = phep(5,i)
             endif
          endif
       enddo
@@ -252,50 +252,50 @@ c///////////
       seedj=u   !seed for random number generator: for first event
       iwseed = 0   ! no record seed
 
-c Initialize decay of particles
+! Initialize decay of particles
       nrnody=0       !number of particle types without decay (if 0 (default) : all unstable particles decay (at the end only (anti)nucleons, (anti)electrons and muons)
-c Particle code is given as
-c     id=+/-ijkl
-c
-c          mesons--
-c          i=0, j<=k, +/- is sign for j
-c          id=110 for pi0, id=220 for eta, etc.
-c
-c          baryons--
-c          i<=j<=k in general
-c          j<i<k for second state antisymmetric in (i,j), eg. l = 2130
-c
-c          other--
-c          id=1,...,6 for quarks
-c          id=9 for gluon
-c          id=10 for photon
-c          id=11,...,16 for leptons
-c          i=17 for deuteron
-c          i=18 for triton
-c          i=19 for alpha
-c          id=20 for ks, id=-20 for kl
-c
-c          i=21...26 for scalar quarks
-c          i=29 for gluino
-c
-c          i=30 for h-dibaryon
-c
-c          i=31...36 for scalar leptons
-c          i=39 for wino
-c          i=40 for zino
-c
-c          id=80 for w+
-c          id=81,...,83 for higgs mesons (h0, H0, A0, H+)
-c          id=84,...,87 for excited bosons (Z'0, Z''0, W'+)
-c          id=90 for z0
-c
-c          diquarks--
-c          id=+/-ij00, i<j for diquark composed of i,j.
-c
-c Examples : 2130 = lambda, 1330=xi0, 2330=xi-, 3331=omega
-c
-c Conversion from epos to  pdg code can be done using
-c      id_pdg=idtrafo('nxs','pdg',id_epos)
+! Particle code is given as
+!     id=+/-ijkl
+!
+!          mesons--
+!          i=0, j<=k, +/- is sign for j
+!          id=110 for pi0, id=220 for eta, etc.
+!
+!          baryons--
+!          i<=j<=k in general
+!          j<i<k for second state antisymmetric in (i,j), eg. l = 2130
+!
+!          other--
+!          id=1,...,6 for quarks
+!          id=9 for gluon
+!          id=10 for photon
+!          id=11,...,16 for leptons
+!          i=17 for deuteron
+!          i=18 for triton
+!          i=19 for alpha
+!          id=20 for ks, id=-20 for kl
+!
+!          i=21...26 for scalar quarks
+!          i=29 for gluino
+!
+!          i=30 for h-dibaryon
+!
+!          i=31...36 for scalar leptons
+!          i=39 for wino
+!          i=40 for zino
+!
+!          id=80 for w+
+!          id=81,...,83 for higgs mesons (h0, H0, A0, H+)
+!          id=84,...,87 for excited bosons (Z'0, Z''0, W'+)
+!          id=90 for z0
+!
+!          diquarks--
+!          id=+/-ij00, i<j for diquark composed of i,j.
+!
+! Examples : 2130 = lambda, 1330=xi0, 2330=xi-, 3331=omega
+!
+! Conversion from epos to  pdg code can be done using
+!      id_pdg=idtrafo('nxs','pdg',id_epos)
 
       nrnody=nrnody+1
       nody(nrnody)=120     !pi+
@@ -393,14 +393,14 @@ c      id_pdg=idtrafo('nxs','pdg',id_epos)
       fncs=trim(fnnx)//"epos.inics"
       nfncs=len(trim(fncs))
 
-c Debug
+! Debug
       ish=0       !debug level
       ifch=0      !debug output (screen); stderr
       ifmt = 0    ! r messages
-c      ifch=31    !debug output (file)
-c      fnch="epos.debug"
-c      nfnch=index(fnch,' ')-1
-c      open(ifch,file=fnch(1:nfnch),status='unknown')
+!      ifch=31    !debug output (file)
+!      fnch="epos.debug"
+!      nfnch=index(fnch,' ')-1
+!      open(ifch,file=fnch(1:nfnch),status='unknown')
 
 !       These are postponed until init for each event.
 !      nevent = 1  !number of events
@@ -417,7 +417,7 @@ c      open(ifch,file=fnch(1:nfnch),status='unknown')
 !
       istmax = 0      !only final particles (istmax=1 includes mother particles)
 
-c for main program
+! for main program
 !      nevto  = nevent
 !      isho   = ish
 
@@ -425,13 +425,13 @@ c for main program
 
 
 
-c-----------------------------------------------------------------------     
+!-----------------------------------------------------------------------     
       subroutine EposInput(nevto,isho)
-c-----------------------------------------------------------------------     
-c Read informations (new options or parameter change) in the file
-c "epos.param". The unit "ifop" is used in aread. If not used, it will
-c use the default value of all parameters.
-c-----------------------------------------------------------------------     
+!-----------------------------------------------------------------------     
+! Read informations (new options or parameter change) in the file
+! "epos.param". The unit "ifop" is used in aread. If not used, it will
+! use the default value of all parameters.
+!-----------------------------------------------------------------------     
 ! for TempDev
 #include "Zmanagerp.h"   
       include "../epos.inc"
@@ -441,22 +441,22 @@ c-----------------------------------------------------------------------
       open(unit=ifop,file='example.param',status='old')
       call aread
       close(ifop)
-c for main program
+! for main program
       nevto  = nevent
       isho   = ish
       end
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       function rangen()  result(rn)   ! single precision
-c-----------------------------------------------------------------------
-c     generates a random number
+!-----------------------------------------------------------------------
+!     generates a random number
 !         use Cosmos generator 
       implicit none
       real(8):: u
       real(4):: rn
       call rndc(u)
       rn = u
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
 !      include 'epos.inc'
 !      double precision dranf
 ! 1    rangen=sngl(dranf(dble(rangen)))
@@ -467,12 +467,12 @@ c-----------------------------------------------------------------------
 !      return
       end
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
 !      double precision function drangen(dummy)
       function drangen(dummy)  result(u)
-c-----------------------------------------------------------------------
-c     generates a random number
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+!     generates a random number
+!-----------------------------------------------------------------------
 !      include 'epos.inc'
 !      double precision dummy,dranf
 !      drangen=dranf(dummy)
@@ -483,11 +483,11 @@ c-----------------------------------------------------------------------
       call rndc(u)
       
       end
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       function cxrangen(dummy)  result(rn)
-c-----------------------------------------------------------------------
-c     generates a random number
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+!     generates a random number
+!-----------------------------------------------------------------------
 !      include 'epos.inc'
 !      double precision dummy,dranf
 !      cxrangen=sngl(dranf(dummy))
@@ -500,7 +500,7 @@ c-----------------------------------------------------------------------
       rn = u
       end
 
-c Random number generator from CORSIKA *********************************
+! Random number generator from CORSIKA *********************************
 
 
 
@@ -529,15 +529,15 @@ c Random number generator from CORSIKA *********************************
 !      END
 
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       subroutine ranfgt(seed)
-c-----------------------------------------------------------------------
-c Initialize seed in EPOS : read seed (output)
-c Since original output seed and EPOS seed are different,
-c define output seed as : seed=ISEED(3)*1E9+ISEED(2)
-c but only for printing. Important values stored in /eporansto/
-c Important : to be call before ranfst
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+! Initialize seed in EPOS : read seed (output)
+! Since original output seed and EPOS seed are different,
+! define output seed as : seed=ISEED(3)*1E9+ISEED(2)
+! but only for printing. Important values stored in /eporansto/
+! Important : to be call before ranfst
+!-----------------------------------------------------------------------
       IMPLICIT NONE
       INTEGER          KSEQ
       PARAMETER        (KSEQ = 2)
@@ -565,15 +565,15 @@ c-----------------------------------------------------------------------
       return
       end
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       subroutine ranfst(seed)
-c-----------------------------------------------------------------------
-c Initialize seed in EPOS :  restore seed (input)
-c Since original output seed and EPOS seed are different,
-c define output seed as : seed=ISEED(3)*1E9+ISEED(2)
-c but only for printing. Important values restored from /eporansto/
-c Important : to be call after ranfgt
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+! Initialize seed in EPOS :  restore seed (input)
+! Since original output seed and EPOS seed are different,
+! define output seed as : seed=ISEED(3)*1E9+ISEED(2)
+! but only for printing. Important values restored from /eporansto/
+! Important : to be call after ranfgt
+!-----------------------------------------------------------------------
       IMPLICIT NONE
       INTEGER          KSEQ
       PARAMETER        (KSEQ = 2)
@@ -601,20 +601,20 @@ c-----------------------------------------------------------------------
       return
       end
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       subroutine ranflim(seed)
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       double precision seed
       if(seed.gt.1d9)stop'seed larger than 1e9 not possible !'
       end
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       subroutine ranfcv(seed)
-c-----------------------------------------------------------------------
-c Convert input seed to EPOS random number seed
-c Since input seed and EPOS (from Corsika) seed are different,
-c define input seed as : seed=ISEED(3)*1E9+ISEED(2) 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+! Convert input seed to EPOS random number seed
+! Since input seed and EPOS (from Corsika) seed are different,
+! define input seed as : seed=ISEED(3)*1E9+ISEED(2) 
+!-----------------------------------------------------------------------
       IMPLICIT NONE
       COMMON /CRRANMA3/CD,CINT,CM,TWOM24,TWOM48,MODCNS
       DOUBLE PRECISION CD,CINT,CM,TWOM24,TWOM48
@@ -629,15 +629,15 @@ c-----------------------------------------------------------------------
       return
       end
 
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
       subroutine ranfini(seed,iseq,iqq)
-c-----------------------------------------------------------------------
-c Initialize random number sequence iseq with seed
-c if iqq=-1, run first ini
-c    iqq=0 , set what sequence should be used
-c    iqq=1 , initialize sequence for initialization
-c    iqq=2 , initialize sequence for first event
-c-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+! Initialize random number sequence iseq with seed
+! if iqq=-1, run first ini
+!    iqq=0 , set what sequence should be used
+!    iqq=1 , initialize sequence for initialization
+!    iqq=2 , initialize sequence for first event
+!-----------------------------------------------------------------------
       IMPLICIT NONE
       COMMON /CRRANMA3/CD,CINT,CM,TWOM24,TWOM48,MODCNS
       DOUBLE PRECISION CD,CINT,CM,TWOM24,TWOM48
@@ -661,7 +661,7 @@ c-----------------------------------------------------------------------
            stop 'Forbidden !'
         endif
         iiseed(1)=nint(mod(seed,dble(MODCNS)))
-c iiseed(2) and iiseed(3) defined in aread
+! iiseed(2) and iiseed(3) defined in aread
         call RMMAQD(iiseed,iseq,'S') !initialize random number generator
       elseif(iqq.eq.1)then        !dummy sequence for EPOS initialization
         irndmseq=iseq
@@ -677,29 +677,29 @@ c iiseed(2) and iiseed(3) defined in aread
       return
       end
 
-C=======================================================================
+!=======================================================================
 
       SUBROUTINE RMMARD( RVEC,LENV,ISEQ )
 
-C-----------------------------------------------------------------------
-C  C(ONE)X
-C  R(ANDO)M (NUMBER GENERATOR OF) MAR(SAGLIA TYPE) D(OUBLE PRECISION)
-C
-C  THESE ROUTINES (RMMARD,RMMAQD) ARE MODIFIED VERSIONS OF ROUTINES
-C  FROM THE CERN LIBRARIES. DESCRIPTION OF ALGORITHM SEE:
-C               http://consult.cern.ch/shortwrups/v113/top.html
-C  IT HAS BEEN CHECKED THAT RESULTS ARE BIT-IDENTICAL WITH CERN
-C  DOUBLE PRECISION RANDOM NUMBER GENERATOR RMM48, DESCRIBED IN
-C               http://consult.cern.ch/shortwrups/v116/top.html
-C  ARGUMENTS:
-C   RVEC   = DOUBLE PREC. VECTOR FIELD TO BE FILLED WITH RANDOM NUMBERS
-C   LENV   = LENGTH OF VECTOR (# OF RANDNUMBERS TO BE GENERATED)
-C   ISEQ   = # OF RANDOM SEQUENCE
-C
-C  VERSION OF D. HECK FOR DOUBLE PRECISION RANDOM NUMBERS.
-C  ADAPTATION  : T. PIEROG    IK  FZK KARLSRUHE FROM D. HECK VERSION
-C  DATE     : Feb  17, 2009
-C-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+!  C(ONE)X
+!  R(ANDO)M (NUMBER GENERATOR OF) MAR(SAGLIA TYPE) D(OUBLE PRECISION)
+!
+!  THESE ROUTINES (RMMARD,RMMAQD) ARE MODIFIED VERSIONS OF ROUTINES
+!  FROM THE CERN LIBRARIES. DESCRIPTION OF ALGORITHM SEE:
+!               http://consult.cern.ch/shortwrups/v113/top.html
+!  IT HAS BEEN CHECKED THAT RESULTS ARE BIT-IDENTICAL WITH CERN
+!  DOUBLE PRECISION RANDOM NUMBER GENERATOR RMM48, DESCRIBED IN
+!               http://consult.cern.ch/shortwrups/v116/top.html
+!  ARGUMENTS:
+!   RVEC   = DOUBLE PREC. VECTOR FIELD TO BE FILLED WITH RANDOM NUMBERS
+!   LENV   = LENGTH OF VECTOR (# OF RANDNUMBERS TO BE GENERATED)
+!   ISEQ   = # OF RANDOM SEQUENCE
+!
+!  VERSION OF D. HECK FOR DOUBLE PRECISION RANDOM NUMBERS.
+!  ADAPTATION  : T. PIEROG    IK  FZK KARLSRUHE FROM D. HECK VERSION
+!  DATE     : Feb  17, 2009
+!-----------------------------------------------------------------------
 
       IMPLICIT NONE
       INTEGER          KSEQ
@@ -716,7 +716,7 @@ C-----------------------------------------------------------------------
       INTEGER          ISEQ,IVEC,LENV
       SAVE
 
-C-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
 
       IF ( ISEQ .GT. 0  .AND.  ISEQ .LE. KSEQ ) JSEQ = ISEQ
       
@@ -732,7 +732,7 @@ C-----------------------------------------------------------------------
         IF ( C(JSEQ) .LT. 0.D0 ) C(JSEQ)  = C(JSEQ) + CM
         UNI        = UNI - C(JSEQ)
         IF ( UNI .LT. 0.D0 ) UNI = UNI + 1.D0
-C  AN EXACT ZERO HERE IS VERY UNLIKELY, BUT LET'S BE SAFE.
+!  AN EXACT ZERO HERE IS VERY UNLIKELY, BUT LET'S BE SAFE.
         IF ( UNI .EQ. 0.D0 ) UNI = TWOM48
         RVEC(IVEC) = UNI
       ENDDO
@@ -746,28 +746,28 @@ C  AN EXACT ZERO HERE IS VERY UNLIKELY, BUT LET'S BE SAFE.
       RETURN
       END
 
-C=======================================================================
+!=======================================================================
 
       SUBROUTINE RMMAQD( ISEED, ISEQ, CHOPT )
 
-C-----------------------------------------------------------------------
-C  R(ANDO)M (NUMBER GENERATOR OF) MA(RSAGLIA TYPE INITIALIZATION) DOUBLE
-C
-C  SUBROUTINE FOR INITIALIZATION OF RMMARD
-C  THESE ROUTINE RMMAQD IS A MODIFIED VERSION OF ROUTINE RMMAQ FROM
-C  THE CERN LIBRARIES. DESCRIPTION OF ALGORITHM SEE:
-C               http://consult.cern.ch/shortwrups/v113/top.html
-C  FURTHER DETAILS SEE SUBR. RMMARD
-C  ARGUMENTS:
-C   ISEED  = SEED TO INITIALIZE A SEQUENCE (3 INTEGERS)
-C   ISEQ   = # OF RANDOM SEQUENCE
-C   CHOPT  = CHARACTER TO STEER INITIALIZE OPTIONS
-C
-C  CERN PROGLIB# V113    RMMAQ           .VERSION KERNFOR  1.0
-C  ORIG. 01/03/89 FCA + FJ
-C  ADAPTATION  : T. PIEROG    IK  FZK KARLSRUHE FROM D. HECK VERSION
-C  DATE     : Feb  17, 2009
-C-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
+!  R(ANDO)M (NUMBER GENERATOR OF) MA(RSAGLIA TYPE INITIALIZATION) DOUBLE
+!
+!  SUBROUTINE FOR INITIALIZATION OF RMMARD
+!  THESE ROUTINE RMMAQD IS A MODIFIED VERSION OF ROUTINE RMMAQ FROM
+!  THE CERN LIBRARIES. DESCRIPTION OF ALGORITHM SEE:
+!               http://consult.cern.ch/shortwrups/v113/top.html
+!  FURTHER DETAILS SEE SUBR. RMMARD
+!  ARGUMENTS:
+!   ISEED  = SEED TO INITIALIZE A SEQUENCE (3 INTEGERS)
+!   ISEQ   = # OF RANDOM SEQUENCE
+!   CHOPT  = CHARACTER TO STEER INITIALIZE OPTIONS
+!
+!  CERN PROGLIB# V113    RMMAQ           .VERSION KERNFOR  1.0
+!  ORIG. 01/03/89 FCA + FJ
+!  ADAPTATION  : T. PIEROG    IK  FZK KARLSRUHE FROM D. HECK VERSION
+!  DATE     : Feb  17, 2009
+!-----------------------------------------------------------------------
 
       IMPLICIT NONE
       INTEGER          KSEQ
@@ -789,7 +789,7 @@ C-----------------------------------------------------------------------
       DATA             FIRST / .TRUE. /, IORNDM/11/, JSEQ/1/
 
       
-C-----------------------------------------------------------------------
+!-----------------------------------------------------------------------
 
       IF ( FIRST ) THEN
         TWOM24 = 2.D0**(-24)
@@ -851,7 +851,7 @@ C-----------------------------------------------------------------------
           CC    = CINT
           II97  = 97
           IJ97  = 33
-C  COMPLETE INITIALIZATION BY SKIPPING (NTOT2*MODCNS+NTOT) RANDOMNUMBERS
+!  COMPLETE INITIALIZATION BY SKIPPING (NTOT2*MODCNS+NTOT) RANDOMNUMBERS
           NITER = MODCNS
           DO   LOOP2 = 1, NTOT2(JSEQ)+1
             IF ( LOOP2 .GT. NTOT2(JSEQ) ) NITER = NTOT(JSEQ)
