@@ -7,11 +7,11 @@
 #include "Zcode.h"      
 #include "Zptcl.h"      
 #include "Ztrackp.h"
-      record /ptcl/ pj  !  input. projectile
+      type(ptcl):: pj  !  input. projectile
 
       integer,intent(in)::ia, iz ! target A and Z
       real(8),intent(in):: sig  ! cross seccion in mb on this target
-      record /ptcl/ a(*)  !output. generated ptcls
+      type(ptcl):: a(*)  !output. generated ptcls
       integer,intent(out):: ntp  ! # of generated ptcls
 
       integer::ntp2
@@ -20,14 +20,14 @@
 
       integer,parameter::maxloop=10
  
-      record /ptcl/ tg  !
-      record /ptcl/ tgspec(209), pjspec(209)
+      type(ptcl):: tg  !
+      type(ptcl):: tgspec(209), pjspec(209)
       integer:: ntgspec, npjspec, nout
       real(8):: impactp 
 
-c/////////
+!/////////
       integer:: i
-c//////////
+!//////////
       if(ia == 1 ) then
          call cmkptc(knuc, -1, iz, tg)
       elseif(ia > 1 ) then
@@ -38,15 +38,15 @@ c//////////
       endif
 !        if anti-p has  0 K.E, 
 !        only elastic events are obtained; avoid loop
-      if(  pj.code== knuc .and. pj.charge==-1
-     *     .and.  pj.fm.p(4) - pj.mass <=0.0 ) then
-         pj.fm.p(4) = 0.001d0 + pj.mass
-c         write(0,*) ' stopping pbar '
+      if(  pj%code== knuc .and. pj%charge==-1
+     *     .and.  pj%fm%p(4) - pj%mass <=0.0 ) then
+         pj%fm%p(4) = 0.001d0 + pj%mass
+!         write(0,*) ' stopping pbar '
 !           force to p target; otherwise infinite loop.
          call cmkptc(knuc, -1, 1, tg)
       endif
-      tg.fm.p(4) = tg.mass
-      tg.fm.p(1:3)= 0.
+      tg%fm%p(4) = tg%mass
+      tg%fm%p(1:3)= 0.
       loop1 = 0
       loop2 = 0
       ok = .false.
@@ -55,13 +55,13 @@ c         write(0,*) ' stopping pbar '
          call cjam(pj, ia, iz,  a, ntp2, 
      *     pjspec, npjspec, tgspec, ntgspec, inela, impactp)
 
-c          jam cannot disable elastic collision.
-c        for non heavy, we can use total x-section
-c        which includes elastic one, but for heavy
-c        we cannot get elastic cross-section. So we have to 
-c          wait until inelastic collsion for heavy.
-c        
-c//////////////
+!          jam cannot disable elastic collision.
+!        for non heavy, we can use total x-section
+!        which includes elastic one, but for heavy
+!        we cannot get elastic cross-section. So we have to 
+!          wait until inelastic collsion for heavy.
+!        
+!//////////////
 !         if( inela == 0 ) then
 !            sumTE= 0.
 !            write(0, *)
@@ -95,9 +95,9 @@ c//////////////
 !            write(0,*) ' sumTE=',sumTE
 !            write(0,*) ' pj E + tgmass=', pj.fm.p(4) + tg.mass
 !         endif
-c/////////////// 
+!/////////////// 
          if( JamXs == 1 ) then
-            ok = pj.code /= kgnuc .or.  inela /= 0
+            ok = pj%code /= kgnuc .or.  inela /= 0
          elseif(JamXs == 0 ) then
             ok = inela /= 0
          else
@@ -109,8 +109,8 @@ c///////////////
             if(loop1 > maxloop) then
                write(0,*)
      *           'In jam event gen. JamXs=',JamXs, ' inela=',inela
-               write(0,*) 'pj=',pj.code, pj.subcode,pj.charge
-               write(0,*) 'pj KE=',pj.fm.p(4)- pj.mass
+               write(0,*) 'pj=',pj%code, pj%subcode,pj%charge
+               write(0,*) 'pj KE=',pj%fm%p(4)- pj%mass
                write(0,*) 'tg A,Z=', ia,iz
                write(0,*)' generated # of ptcls =',ntp2
                write(0,*) 'event is neglected'
@@ -125,16 +125,16 @@ c///////////////
 !                           so don't worry)
 #if defined ShowFragment 
          write(0,'(a,3i4,a,1p,g12.3,a, l)')
-     *        'pj=', pj.code, pj.subcode, pj.charge,
-     *        'KE=', pj.fm.p(4)- pj.mass, ' ok=',ok
+     *        'pj=', pj%code, pj%subcode, pj%charge,
+     *        'KE=', pj%fm%p(4)- pj%mass, ' ok=',ok
          write(0,*) '# of  pj spec=',npjspec
          write(0,*) 'target A,Z =',ia, iz
          write(0,*) '# of  tg spec=',ntgspec
 
          do i = 1, ntp2
             write(0,'(a,3i5,1p,g12.4)') '---',
-     *          a(i).code, a(i).subcode, a(i).charge, 
-     *         a(i).fm.p(4) - a(i).mass
+     *          a(i)%code, a(i)%subcode, a(i)%charge, 
+     *         a(i)%fm%p(4) - a(i)%mass
          enddo
 #endif
 
@@ -145,17 +145,17 @@ c///////////////
             else
                nout = 0
             endif
-c/////////
+!/////////
 #if defined ShowFragment
             write(0,*) 'pj spec-->frag=',nout
             do i = 1, nout
                write(0,'(a,3i4,1p,g12.3)')
-     *          '***p fr', a(ntp2+i).code, 
-     *         a(ntp2+i).subcode,  a(ntp2+i).charge, 
-     *         a(ntp2+i).fm.p(4)-a(ntp2+i).mass
+     *          '***p fr', a(ntp2+i)%code, 
+     *         a(ntp2+i)%subcode,  a(ntp2+i)%charge, 
+     *         a(ntp2+i)%fm%p(4)-a(ntp2+i)%mass
             enddo
 #endif
-c/////////// 
+!/////////// 
             ntp2 = ntp2 + nout
             if(ntgspec > 0 ) then
                call cjamTgSpec(pj, tg,
@@ -163,18 +163,18 @@ c///////////
             else
                nout = 0
             endif
-c/////////
+!/////////
 #if defined ShowFragment
             write(0,*) 'tg spec-->frag=',nout
             do i = 1, nout
                write(0,'(a,3i4,1p,g12.3)')
-     *          '^^^t fr', a(ntp2+i).code, 
-     *         a(ntp2+i).subcode,  a(ntp2+i).charge, 
-     *         a(ntp2+i).fm.p(4)-a(ntp2+i).mass
+     *          '^^^t fr', a(ntp2+i)%code, 
+     *         a(ntp2+i)%subcode,  a(ntp2+i)%charge, 
+     *         a(ntp2+i)%fm%p(4)-a(ntp2+i)%mass
             enddo
             write(0,*)
 #endif
-c//////////////
+!//////////////
             ntp2 = ntp2 + nout
             call cjamEconsv(pj, tg, a, ntp2, ntp, ok)
             if(.not. ok ) then
@@ -208,12 +208,12 @@ c//////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zkfcode.h"
-      record /ptcl/ pj  ! input.  projectile
-      record /ptcl/ tg  ! input.  target
+      type(ptcl):: pj  ! input.  projectile
+      type(ptcl):: tg  ! input.  target
       integer,intent(in):: ntp2   ! # of ptcls in a
       integer,intent(out):: ntp   ! # of ptcls in a (after dropping
                                  ! spectator n
-      record /ptcl/a(ntp2)   ! in/out. produced ptcles
+      type(ptcl)::a(ntp2)   ! in/out. produced ptcles
       logical,intent(out):: ok  ! if E consv, ok=.true. else f
       
       integer i
@@ -233,13 +233,13 @@ c//////////////
       sumTE = 0.
       ntp = 0
       do i = 1, ntp2
-         sumTE = a(i).fm.p(4)  + sumTE 
+         sumTE = a(i)%fm%p(4)  + sumTE 
          ntp = ntp + 1
          a(ntp) =  a(i)
       enddo
-      if( abs( sumTE/(pj.fm.p(4) + tg.mass) - 1.0d0) > eps ) then
-         if( pj.code == kgnuc ) then
-            projA = pj.subcode
+      if( abs( sumTE/(pj%fm%p(4) + tg%mass) - 1.0d0) > eps ) then
+         if( pj%code == kgnuc ) then
+            projA = pj%subcode
          else
             projA= 1.
          endif
@@ -254,10 +254,10 @@ c//////////////
       end
 
       subroutine cjamini(pj, tg, sig)
-c      This must be called before generating one exclusive 
-c      event (call jamev) 
-c      implicit none  ! this cannot be used since jam1.inc uses
-c      implicit double (...)
+!      This must be called before generating one exclusive 
+!      event (call jamev) 
+!      implicit none  ! this cannot be used since jam1.inc uses
+!      implicit double (...)
 #include "jam1.inc"
 #include "jam2.inc"
 
@@ -268,7 +268,7 @@ c      implicit double (...)
 #include "Zevhnv.h"
 #include "Zcode.h"
 #include "Zmass.h"
-      record /ptcl /pj, tg  ! input 
+      type(ptcl)::pj, tg  ! input 
       real(8),intent(in)::sig  ! input  cross-sction on target tg in mb
                          ! used to calculate the impact parameter
 
@@ -285,8 +285,8 @@ c      implicit double (...)
          mevent = 1
          bmin = 0.
          bmax = -7.50D0           ! maximum impact parameter (1530mb)Au  
-c            for pp collison. bmax is not used.?
-c            for AA bmax=0 make loop
+!            for pp collison. bmax is not used.?
+!            for AA bmax=0 make loop
          dt = 100.d0
          nstep =1
          mstc(8) = 0       ! job mode
@@ -296,24 +296,27 @@ c            for AA bmax=0 make loop
          mstc(81)=0  ! neglect hard scattering (for meson)
          frame = 'lab'
          fname(1) = '0'
-         fname(2) = '/dev/null'
-         fname(3) = '/dev/null'
+         fname(2) = '/dev/null'  ! IO mstc(37)'s target.
+!     fname(3) = '/dev/null'   ! IO mstc(38)'s target
+                           ! Gfortran cannot open simult.
+                 ! with mstc(37), so .
+         fname(3)='/dev/stderr' 
       endif
       bmax = - sqrt( sig/3.141592/10. )  ! in fm  must be < 0
       call ccos2jamsymbl(pj, proj)  ! make projectile symbol
-c               such as proj = 'k+'
+!               such as proj = 'k+'
       call ccos2jamsymbl(tg, targ)
 
-c	targ = '14:7'
-c	targ = 'p'
-c	targ = 'n'
-c	targ='197Au   '
-c	targ = '4:2'
-c	targ = '2:1'
-      if(pj.code == kgnuc ) then
-         write(cwin, '(f12.3,"gev")')  (pj.fm.p(4)-pj.mass)/pj.subcode
+!	targ = '14:7'
+!	targ = 'p'
+!	targ = 'n'
+!	targ='197Au   '
+!	targ = '4:2'
+!	targ = '2:1'
+      if(pj%code == kgnuc ) then
+         write(cwin, '(f12.3,"gev")')  (pj%fm%p(4)-pj%mass)/pj%subcode
       else
-         write(cwin, '(f12.3,"gev")')  (pj.fm.p(4)-pj.mass)
+         write(cwin, '(f12.3,"gev")')  (pj%fm%p(4)-pj%mass)
       endif
       call jaminit(mevent, bmin, bmax, dt, nstep, frame, proj, targ,
      *  cwin)
@@ -322,82 +325,82 @@ c	targ = '2:1'
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
-      record /ptcl/ pj  ! input. code, subcode, charge 
+      type(ptcl):: pj  ! input. code, subcode, charge 
                         ! iouput. incase of Lambda, pj is
                         ! modified to be a neutron
       character*8 symb  ! output. symbol used by jam
 
       integer nc
 
-      if(pj.code .eq. kpion) then
-         if(pj.charge .eq. 1) then
+      if(pj%code .eq. kpion) then
+         if(pj%charge .eq. 1) then
             symb = 'pi+'
-         elseif(pj.charge .eq. 0) then
+         elseif(pj%charge .eq. 0) then
             write(0,*)
      *       'pi0 cannot be col. projectile in jam'
             stop
          else
             symb = 'pi-'
          endif
-      elseif(pj.code .eq. kkaon) then
-         if(pj.charge .eq. 1) then
+      elseif(pj%code .eq. kkaon) then
+         if(pj%charge .eq. 1) then
             symb = 'k+'
-         elseif(pj.charge .eq. -1) then
+         elseif(pj%charge .eq. -1) then
             symb = 'k-'
          else
            symb = 'k0'
-c            write(0,*)  ' k0 cannot be proj. in jam'
-c            stop
+!            write(0,*)  ' k0 cannot be proj. in jam'
+!            stop
          endif
-      elseif(pj.code .eq. knuc ) then
-         if(pj.charge .eq. 1) then
+      elseif(pj%code .eq. knuc ) then
+         if(pj%charge .eq. 1) then
             symb = 'p'
-         elseif(pj.charge .eq.  -1 ) then
+         elseif(pj%charge .eq.  -1 ) then
             symb = 'pbar'
-         elseif(pj.subcode .eq. regptcl) then
+         elseif(pj%subcode .eq. regptcl) then
             symb = 'n'
          else
             symb = 'nbar'
          endif
-      elseif(pj.code .eq. kgnuc) then
-         write(symb, '(i3,":", i3)' ) pj.subcode, 
-     *       pj.subcode-pj.charge
-c            remove blanks
+      elseif(pj%code .eq. kgnuc) then
+         write(symb, '(i3,":", i3)' ) pj%subcode, 
+     *       pj%subcode-pj%charge
+!            remove blanks
          call kseblk(symb, "*", nc)  !  A:N say 207:125
-      elseif( pj.code >= klambda .and. pj.code <= klambdac ) then
-c          regard it as neutron                                                
+      elseif( pj%code >= klambda .and. pj%code <= klambdac ) then
+!          regard it as neutron                                                
          call cmkptc(knuc, -1, 0, pj)
          call cadjm(pj, pj)
          symb = 'n'
-      elseif( pj.code == kbomega ) then
-c         very rare: regard it as proton
+      elseif( pj%code == kbomega ) then
+!         very rare: regard it as proton
          call cmkptc(knuc, -1, 1, pj)
          call cadjm(pj, pj)
          symb = 'p'
       else
-         write(0,*) 'code=',pj.code, ' charge=',pj.charge
+         write(0,*) 'code=',pj%code, ' charge=',pj%charge
          write(0,*) ' not supported in jam'
          stop
       endif
       end
       subroutine cjam(pj, ia, iz,  a, ntp, 
      *     pjspec, npjspec, tgspec, ntgspec, inela, impactp)
-c      implicit none  ! this cannot be used since jam1.inc uses
-c      implicit double (...)
+!      implicit none  ! this cannot be used since jam1.inc uses
+!      implicit double (...)
 #include "jam1.inc"
 #include "jam2.inc"
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Ztrackp.h"
 
-      record /ptcl/pj  ! input incident ptcl 
+      type(ptcl)::pj  ! input incident ptcl 
       integer,intent(in)::ia  !  target A
       integer,intent(in)::iz  !  target Z
-      record /ptcl/a(*)
+      type(ptcl)::a(*)
       integer,intent(out):: ntp ! # of non spectator ptcls stored in a
-      record /ptcl/pjspec(*) !output. projectile spector
+      type(ptcl)::pjspec(*) !output. projectile spector
       integer,intent(out):: npjspec ! # of ptcls in pjspec
-      record /ptcl/ tgspec(*) !output  target spectator
+      type(ptcl):: tgspec(*) !output  target spectator
       integer,intent(out):: ntgspec ! # of ptcls in tgspec
       integer,intent(out):: inela ! =0  elastic event
                                   ! =1  inelastic event
@@ -406,16 +409,16 @@ c      implicit double (...)
       integer code, subcode, charge
       integer iev/1/
       real(8)::pprobt, u, pprobp, probp
-      record /ptcl/ aptcl
+      type(ptcl):: aptcl
       integer::nn, hn, rn  ! # of free N, Heavy ions and Remnant
       save
       pprobt = iz
       pprobt = pprobt/ia   !  rough proton probabilty of target spectator
-      if( pj.code == kgnuc ) then
-         pprobp = pj.charge
-         pprobp = pprobp/pj.subcode
-         probp = (iz+pj.charge)
-         probp = probp/(ia+pj.subcode)
+      if( pj%code == kgnuc ) then
+         pprobp = pj%charge
+         pprobp = pprobp/pj%subcode
+         probp = (iz+pj%charge)
+         probp = probp/(ia+pj%subcode)
       else
          probp = pprobt
       endif
@@ -424,10 +427,10 @@ c      implicit double (...)
       inela = 0
       npjspec = 0
       ntgspec = 0
-c////////////
-c      tgTE =0.
-c      pjTE = 0.
-c///////////
+!////////////
+!      tgTE =0.
+!      pjTE = 0.
+!///////////
 !      if( ia == 1  ) then
 !!         if target is p/n,
 !         if( pj.code<=knuc .and. pj.code >= kpion  ) then
@@ -452,23 +455,23 @@ c///////////
                if( abs( k(7,i) ) > 1 ) then
                   inela = 1
                endif
-c///////////////////
-c               write(0,'(a, 4i4,2x,4i4)')
-c     *          'k(7,i)=',k(7,i), code, subcode, charge,
-c     *           pj.code, pj.subcode, pj.charge,  ia
-c///////////
+!///////////////////
+!               write(0,'(a, 4i4,2x,4i4)')
+!     *          'k(7,i)=',k(7,i), code, subcode, charge,
+!     *           pj.code, pj.subcode, pj.charge,  ia
+!///////////
 !                 target spectator treatment.  (original Jam 
 !                 breaks  spectator heavy target  into nucoleons;
 !                 and seems to be almost neutrons. We reasign the chage
-c               Nara san's spec is -1 for target spectator but seems to be
-c               incorrect and 1 must be used
+!               Nara san's spec is -1 for target spectator but seems to be
+!               incorrect and 1 must be used
                call cmkptc(code, subcode, charge, aptcl)
-               aptcl.fm.p(1:4) = p(1:4,i)  ! jam is T.E  (manual==>K.E=> false).
-c//////////////
+               aptcl%fm%p(1:4) = p(1:4,i)  ! jam is T.E  (manual==>K.E=> false).
+!//////////////
 !               write(0,'(a, 4i4, 1p,4g12.3)')
 !     *            'k(7,=',k(7,i), code, subcode, charge,
 !     *            p(1:4,i)
-c/////////////
+!/////////////
                if( k(7,i) == 1 ) then  ! target spec.
 !                      re-assign the charge****NO NEED NOW****
 !                  call rndc(u)
@@ -508,8 +511,8 @@ c/////////////
                   ntp = ntp + 1
                   a(ntp) = aptcl
 !      **** NO NEED NOW****
-c                     jam charge assignment for N is stragne, we randomly
-c                     re-assign it
+!                     jam charge assignment for N is stragne, we randomly
+!                     re-assign it
 !                  if( code == knuc .and. subcode /= antip ) then
 !                     call rndc(u)
 !                     if(u < probp) then
@@ -520,20 +523,20 @@ c                     re-assign it
 !                  endif
                endif
             endif
-c            write(*,*) i, k(2,i), p(1,i), p(2,i), p(3,i),
-c     *             p(4,i), p(5,i)
+!            write(*,*) i, k(2,i), p(1,i), p(2,i), p(3,i),
+!     *             p(4,i), p(5,i)
          endif
       enddo
 
-c///////////////
-c      if( pj.fm.p(4) > inci.fm.p(4)*0.98 ) then
-c         write(*,*) 'pjTE=',pjTE, ' pj. =',pj.fm.p(4)
-c         write(*,*) 'tgKE=',tgTE, ' Mt=', pjTE+tgTE-pj.fm.p(4)
-c         write(*,*)
-c         write(*,*) "====================="
-c         write(*,*)
-c      endif
-c/////////////////
+!///////////////
+!      if( pj.fm.p(4) > inci.fm.p(4)*0.98 ) then
+!         write(*,*) 'pjTE=',pjTE, ' pj. =',pj.fm.p(4)
+!         write(*,*) 'tgKE=',tgTE, ' Mt=', pjTE+tgTE-pj.fm.p(4)
+!         write(*,*)
+!         write(*,*) "====================="
+!         write(*,*)
+!      endif
+!/////////////////
       impactp = pard(2) ! is in jam2.inc
       end
       subroutine  cjamPjSpec(pj, tg,
@@ -542,13 +545,13 @@ c/////////////////
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
-      record /ptcl/ pj ! input. proj.
-      record /ptcl/ tg ! //     taget
-      record /ptcl/pjspec(*) !input. projectile spector
+      type(ptcl):: pj ! input. proj.
+      type(ptcl):: tg ! //     taget
+      type(ptcl)::pjspec(*) !input. projectile spector
       integer,intent(in):: npjspec ! # of ptcls in pjspec
       real(8),intent(in):: impactp ! impact parameter in fm of the interaction
       integer,intent(in):: inela   ! inela or ela event
-      record /ptcl/a(*)  ! output.  fragment from the spectator
+      type(ptcl)::a(*)  ! output.  fragment from the spectator
       integer,intent(out):: nout ! # of ptcls in a
 
       integer::iat, izt  !  target A, Z
@@ -565,19 +568,19 @@ c/////////////////
       break = .true.
       nout = 0
       n = 0
-      if(tg.code == kgnuc) then
-         iat = tg.subcode
+      if(tg%code == kgnuc) then
+         iat = tg%subcode
       else
          iat = 1
       endif
-      izt = tg.charge
-      if( inela == 0 .and. pj.code /= kgnuc ) then  !  elastic event. proj. is only 1  spectator
+      izt = tg%charge
+      if( inela == 0 .and. pj%code /= kgnuc ) then  !  elastic event. proj. is only 1  spectator
          nout = nout + 1
          a(nout) = pjspec(1)
       elseif( iat == 1) then  ! fragm cannot treat this case
          break=.false.
       elseif( npjspec > 0 ) then  
-         pjA = pj.subcode
+         pjA = pj%subcode
          if( pjA  > 56 .and. iat > 56) then
             call csampNucFrag(pj, iat, izt, npjspec,
      *             a, nout)
@@ -586,7 +589,7 @@ c/////////////////
             call cuseFragNHR(iat, izt,  pjA, pjZ, pjspec,  npjspec,
      *            oA, oZ, a, nout)
          else
-            nw = pj.subcode - npjspec
+            nw = pj%subcode - npjspec
             !    use fragm (target comes 1st)
             call cusefragm(iat, pjA, nw, pjspec,
      *           impactp, oA, oZ,   a, nout)
@@ -612,10 +615,10 @@ c/////////////////
 #include "Zcode.h"
       integer,intent(in):: pjA, pjZ  ! projectil A,Z  A<=56
       integer,intent(in)::iat, izt  !  target A,Z  A>=56
-      record /ptcl/tgspec(*)  ! input.  spectator nucleon info.
+      type(ptcl)::tgspec(*)  ! input.  spectator nucleon info.
       integer,intent(in):: ntgspec ! # of target spectator in tgspec
       integer,intent(out):: oA(209),  oZ(209) ! working array
-      record /ptcl/a(*)  ! output.  fragment from the target
+      type(ptcl)::a(*)  ! output.  fragment from the target
       integer,intent(out):: nout ! # of ptcls in a
 
 
@@ -630,17 +633,17 @@ c/////////////////
          if( oA(i) == 1 ) then
             n = n + 1           ! n/p
             a(i) =  tgspec(n)
-            a(i).charge = oZ(i)
+            a(i)%charge = oZ(i)
          else
-            a(i).fm.p(1:4) = 0.   
+            a(i)%fm%p(1:4) = 0.   
             do j = 1, oA(i)
                n = n + 1
-               a(i).fm.p(1:4) = a(i).fm.p(1:4)
-     *              + tgspec(n).fm.p(1:4)
+               a(i)%fm%p(1:4) = a(i)%fm%p(1:4)
+     *              + tgspec(n)%fm%p(1:4)
             enddo
             call cmkptc(kgnuc, oA(i), oZ(i), a(i))
-            a(i).mass = sqrt( a(i).fm.p(4)**2 
-     *           -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
+            a(i)%mass = sqrt( a(i)%fm%p(4)**2 
+     *           -   dot_product(a(i)%fm%p(1:3), a(i)%fm%p(1:3)) )
          endif
       enddo
       end subroutine cusefragNHR
@@ -655,12 +658,12 @@ c/////////////////
       integer,intent(in):: iat  !  target A
       integer,intent(in):: pjA ! projectile A
       integer,intent(in):: nw  ! woonded N
-      record /ptcl/pjspec(*)  ! input projectile spectator info
+      type(ptcl)::pjspec(*)  ! input projectile spectator info
       real(8),intent(in):: impactp ! impact parameter in fm of the interaction
       integer,intent(out):: oA(209),  oZ(209)
              !  this is used inside of this prog. 
       integer,intent(out):: nout ! # of fragment in oA, oZ and a 
-      record /ptcl/ a(*)  ! output.  fragment from the spectator
+      type(ptcl):: a(*)  ! output.  fragment from the spectator
 
 
       integer:: i, j,  n
@@ -674,26 +677,26 @@ c/////////////////
             if( oZ(i) > 1 ) then
                oZ(i) = 1  ! never seen, but for safety.  
             endif
-            a(i).charge =  oZ(i)
+            a(i)%charge =  oZ(i)
          else
-            a(i).fm.p(1:4) = 0.   
+            a(i)%fm%p(1:4) = 0.   
             do j = 1, oA(i)
                n = n + 1
-               a(i).fm.p(1:4) = a(i).fm.p(1:4)
-     *              + pjspec(n).fm.p(1:4)
+               a(i)%fm%p(1:4) = a(i)%fm%p(1:4)
+     *              + pjspec(n)%fm%p(1:4)
             enddo
             call cmkptc(kgnuc, oA(i), oZ(i), a(i) )
 !!            call cmkptc(kgnuc, oA(i), 1, a(i))
-            a(i).mass = sqrt( a(i).fm.p(4)**2 
-     *           -   dot_product(a(i).fm.p(1:3), a(i).fm.p(1:3)) )
+            a(i)%mass = sqrt( a(i)%fm%p(4)**2 
+     *           -   dot_product(a(i)%fm%p(1:3), a(i)%fm%p(1:3)) )
             if(oA(i) == 2) then ! d
-               a(i).charge = 1
+               a(i)%charge = 1
             elseif( oA(i) <= 4 ) then ! He3 or He4
-               a(i).charge = 2
+               a(i)%charge = 2
             elseif( oA(i) < 20 ) then
-               a(i).charge = max(3.0, oA(i)*0.5)
+               a(i)%charge = max(3.0, oA(i)*0.5)
             else
-               a(i).charge = oA(i)*0.4
+               a(i)%charge = oA(i)*0.4
             endif
          endif
       enddo
@@ -703,40 +706,40 @@ c/////////////////
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
-      record /ptcl/ p0 ! input. nucleus before interaction
+      type(ptcl):: p0 ! input. nucleus before interaction
       integer,intent(in):: nspec ! among p0, nspec is spectator nuc.
-      record /ptcl/ spec(nspec) ! inut. spectator nucleons
-      record /ptcl/a   ! output. npec nucleon is made to be a nucleus
+      type(ptcl):: spec(nspec) ! inut. spectator nucleons
+      type(ptcl)::a   ! output. npec nucleon is made to be a nucleus
 
       integer Zsum 
       integer i
-      a.charge = 0
-      a.fm.p(:) = 0
+      a%charge = 0
+      a%fm%p(:) = 0
       if( nspec > 1 ) then
          do i =1, nspec
-            a.charge = a.charge + spec(i).charge
-            a.fm.p(:) = a.fm.p(:) + spec(i).fm.p(:)
+            a%charge = a%charge + spec(i)%charge
+            a%fm%p(:) = a%fm%p(:) + spec(i)%fm%p(:)
          enddo
-         a.subcode = nspec
-         a.code = kgnuc
-         if( a.charge <= 0 ) then 
+         a%subcode = nspec
+         a%code = kgnuc
+         if( a%charge <= 0 ) then 
 !               very very rare; happend when target is H
 !              and pj is He.  
 !            write(0,*) 'In cjamNoFrag.  p0=',p0.fm.p(1:4) 
 !            write(0,*) 'nspec =', nspec
 !            write(0,*) ' charge sum=',0
 !        if Z=0 is kept, dpmjet will die by NEGATIVE ENERGY.
-            a.charge = 1
+            a%charge = 1
 !              next is for safety
-         elseif( a.charge >= nspec  .and. nspec > 1 ) then
-            a.charge = max(nspec/2, 1)
+         elseif( a%charge >= nspec  .and. nspec > 1 ) then
+            a%charge = max(nspec/2, 1)
          endif
-         a.mass =  a.fm.p(4)**2 -
-     *    dot_product(a.fm.p(1:3), a.fm.p(1:3))
+         a%mass =  a%fm%p(4)**2 -
+     *    dot_product(a%fm%p(1:3), a%fm%p(1:3))
 !         if(a.mass < 0. ) then
 !            write(*,*) 'errp mass2',   a.mass
 !         endif
-         a.mass = sqrt(a.mass)
+         a%mass = sqrt(a%mass)
       else
          a = spec(1)
       endif
@@ -748,13 +751,13 @@ c/////////////////
       implicit none
 #include "Zptcl.h"
 #include "Zcode.h"
-      record /ptcl/ pj ! input. proj.
-      record /ptcl/ tg ! input. target.
-      record /ptcl/tgspec(*) !input. target spectator
+      type(ptcl):: pj ! input. proj.
+      type(ptcl):: tg ! input. target.
+      type(ptcl)::tgspec(*) !input. target spectator
       integer,intent(in):: ntgspec ! # of ptcls in tgspec
       real(8):: impactp  ! impact parameter in fm
       integer,intent(in):: inela  ! ela/inela flag
-      record /ptcl/a(*)  ! output.  fragment from the spectator
+      type(ptcl)::a(*)  ! output.  fragment from the spectator
       integer,intent(out):: nout ! # of ptcls in a
 
       integer::iat, izt  !  target A,Z
@@ -768,18 +771,18 @@ c/////////////////
 !       if target A>56 use cSampFragNHR by using proj and targ as they are
       integer,save:: nwrong=0
       logical:: break
-      if( tg.code == kgnuc) then
-         iat = tg.subcode
+      if( tg%code == kgnuc) then
+         iat = tg%subcode
       else
          iat = 1
       endif
-      izt = tg.charge
-      if(pj.code == kgnuc ) then
-         pjA = pj.subcode
+      izt = tg%charge
+      if(pj%code == kgnuc ) then
+         pjA = pj%subcode
       else
          pjA=1
       endif
-      pjZ = pj.charge
+      pjZ = pj%charge
 
       break = .true.
       nout = 0
@@ -788,9 +791,9 @@ c/////////////////
          nout = nout + 1                      !   inela == 0 is redunant
          a(nout) = tgspec(1)
       elseif( ntgspec > 0 ) then  
-         if( iat > 56 .and. pj.subcode > 56) then
-            call csampNucFrag(tg, int(pj.subcode),
-     *           int(pj.charge), ntgspec, a, nout)
+         if( iat > 56 .and. pj%subcode > 56) then
+            call csampNucFrag(tg, int(pj%subcode),
+     *           int(pj%charge), ntgspec, a, nout)
          elseif( iat > 56 ) then !  pjA <=56
             call cuseFragNHR(pjA, pjZ, iat, izt, tgspec,  ntgspec,
      *            oA, oZ, a, nout)            
