@@ -94,6 +94,24 @@ c...] AO, 050614
           endif
 
           iang=0
+c.....2010/6/29 pjdec() does not work for X(1690) 
+c... because invariant  mass of some decay chanel chennel may be
+c...less than than the mass of daughter.
+c         if(abs(kf0).eq.13322.or.abs(kf0).eq.13312) iang=1
+          ibar=k(9,ip)
+          if(abs(ibar).eq.3) iang=1
+          if(id0.eq.id_charmb) iang=0
+          if(id0.eq.id_bottb) iang=0
+          if(id0.eq.id_omega) iang=0
+          if(abs(kf0).eq.3122) iang=0 ! Lambada
+          if(abs(kf0).eq.3112) iang=0 ! Sigma-
+          if(abs(kf0).eq.3212) iang=0 ! Sigma0
+          if(abs(kf0).eq.3222) iang=0 ! Sigma+
+          if(abs(kf0).eq.3312) iang=0 ! Xi-
+          if(abs(kf0).eq.3322) iang=0 ! Xi0
+          if(abs(kf0).eq.3314) iang=0 ! Xi*-
+          if(abs(kf0).eq.3324) iang=0 ! Xi*0
+
           iswang=mstc(61)
 c         if(k(1,ip).eq.2.and.abs(k(9,ip)).eq.3) then
           if(k(1,ip).eq.2.and.kq(1,ip).eq.999999) then  ! resonance
@@ -104,6 +122,7 @@ c         if(k(1,ip).eq.2.and.abs(k(9,ip)).eq.3) then
             endif
           endif
 
+
           if(mdcy(kc0,1).eq.0) then
             write(check(1),'(''kc0='',i3)')kc0
             write(check(2),'(3i10)')mste(21),mste(22),kcp(1,1)
@@ -1111,7 +1130,7 @@ c======================================================================*
       jamdtim=1d+34
       ks1=mod(abs(ks01),10)
       if(kc.le.0.or.kc.gt.mstu(6)) then
-       write(check(1),'(''kc='',i4)')kc
+       write(check(1),'(''kc kf='',i4,i9)')kc,kf
        call jamerrm(30,1,'(jamdtim:)invalid kc')
       endif
 
