@@ -1,5 +1,5 @@
-c        printout error message on error out.
-c
+!        printout error message on error out.
+!
       subroutine cerrorMsg(msg, needrtn)
       implicit none
 #include  "Zmanagerp.h"
@@ -15,7 +15,7 @@ c
          write(ErrorOut, '(a)') msg(1:klena(msg))
       endif
       if(needrtn .eq. 0)  then
-#if defined (PCLinuxIFC64) || (PCLinuxIFC)
+#if defined (PCLinuxIFC64) || (PCLinuxIFC) || (MacIFC)
          call TRACEBACKQQ()
 #endif
          call cbackTrace(dummy)
