@@ -1,11 +1,11 @@
-c          test cpiMuDecay      
+!          test cpiMuDecay      
       implicit none
 #include  "Zptcl.h"
 #include  "Zcode.h"
       
-      record /ptcl/ pj    !  input. pion
+      type(ptcl):: pj    !  input. pion
       logical mupol    !  if T, polarization is taken into account
-      record /ptcl/ a(2)   ! to store decay product
+      type(ptcl):: a(2)   ! to store decay product
       integer np     !    no. of ptcls stored in a 
       real*8   polari
       integer subcode, charge
