@@ -1,8 +1,8 @@
-c      *******************
+!      *******************
       subroutine cintModels(from)
-c
-c           establish the energy bound for the given interaction model.
-c          and corresponding init.
+!
+!           establish the energy bound for the given interaction model.
+!          and corresponding init.
       implicit none
 #include  "Zmanagerp.h"
 #include  "Zmanager.h"
@@ -24,19 +24,19 @@ c          and corresponding init.
          ModelList2(i) = ' '
          InteErg2(i) = 2.d12  ! GeV 10^21 eV
       enddo
-c             ModelList       InteErg
-c              "xxx"            100.
-c              "yyy"            1.d12      ====>  xxx if E< 100  else yyy
-c
-c              "xxx"            1.d12      ====>  xxx at entier energy.
-c
+!             ModelList       InteErg
+!              "xxx"            100.
+!              "yyy"            1.d12      ====>  xxx if E< 100  else yyy
+!
+!              "xxx"            1.d12      ====>  xxx at entier energy.
+!
       IntModel(64:64) = '/'
       if( XsecModel == " ") then
          XsecModel = IntModel
       else
          XsecModel(64:64) = '/'
       endif
-
+ 
       read(IntModel, *, Err=100)
      *    (ModelList(i), InteErg(i), i=1, MaxIntMdls)
       read(XsecModel, *, Err=100)
@@ -62,9 +62,9 @@ c
       do i = 1, NoOfMdls-1
 !         if(InteErg(i) .ge. InteErg(i+1)) then
          if(InteErg(i) > InteErg(i+1)) then  ! v7.633
-c                 energy region invalid
+!                 energy region invalid
             call cerrorMsg(
-     *           'IntModle is invalid; energy region not ascending', 1)
+     *           'IntModel is invalid; energy region not ascending', 1)
             call cerrorMsg(IntModel, 0)
          elseif(InteErg(i) == InteErg(i+1)) then ! v7.633
 !             a model written between(i) and (i+1)
@@ -74,8 +74,8 @@ c                 energy region invalid
             ! issue some message
             write(0,*) '================================='
             write(0,*)
-     *        i,'-th and ',i+1,'-th energy in IntModle are same' 
-            write(0,*) 'The model specified is',ModelList(i+1), '.'
+     *        i,'-th and ',i+1,'-th energy in IntModel are same' 
+            write(0,*) 'The model specified is ',ModelList(i+1), '.'
             write(0,*) 'It will not be used explicitly but might be'
             write(0,*) 'used when some model needs help for a '
             write(0,*) 'specific particle. dpmjet3 is a good  ' 
@@ -84,27 +84,28 @@ c                 energy region invalid
          endif
 
       enddo
-      do i = 1, NoOfMdls2-1
-         if(InteErg2(i) > InteErg2(i+1)) then  
-c                 energy region invalid
-            call cerrorMsg(
+      if( NoOfMdls2 /=  NoOfMdls .or.
+     &    any(InteErg(1:NoOfMdls) /= InteErg2(1:NoOfMdls)) ) then
+         do i = 1, NoOfMdls2-1
+            if(InteErg2(i) > InteErg2(i+1)) then  
+!                 energy region invalid
+               call cerrorMsg(
      *           'XsecModel is invalid; energy region not ascending', 1)
-            call cerrorMsg(XsecModel, 0)
-         elseif(InteErg2(i) == InteErg2(i+1)) then
-            write(0,*) '================================='
-            write(0,*)
-     *        i,'-th and ',i+1,'-th energy in IntModle are same' 
-            write(0,*) 'The model specified is',ModelList2(i+1), '.'
-            write(0,*) 'It will not be used explicitly but might be'
-            write(0,*) 'used when some model needs help for a '
-            write(0,*) 'specific particle. dpmjet3 is a good  ' 
-            write(0,*) 'candidate of such a model'
-            write(0,*) '================================='
-         endif
-
-      enddo
-
-c         exam models
+               call cerrorMsg(XsecModel, 0)
+            elseif(InteErg2(i) == InteErg2(i+1)) then
+             write(0,*) '================================='
+             write(0,*)
+     *        i,'-th and ',i+1,'-th energy in IntModel are same' 
+             write(0,*) 'The model specified is ',ModelList2(i+1), '.'
+             write(0,*) 'It will not be used explicitly but might be'
+             write(0,*) 'used when some model needs help for a '
+             write(0,*) 'specific particle. dpmjet3 is a good  ' 
+             write(0,*) 'candidate of such a model'
+             write(0,*) '================================='
+          endif
+       enddo
+      endif
+!         exam models
       do i = 1, NoOfMdls
          do j = 1, nmdls
             if( ModelList(i) .eq.  RegMdls(j) ) goto 25
@@ -113,7 +114,7 @@ c         exam models
          call cerrorMsg('above model is not yet registered', 0)
  25      continue
       enddo
-c         exam models
+!         exam models
       do i = 1, NoOfMdls2
          do j = 1, nmdls
             if( ModelList2(i) .eq.  RegMdls(j) ) goto 28
@@ -123,15 +124,15 @@ c         exam models
  28      continue
       enddo
 
-c
+!
       if( index(IntModel, 'fritiof1.6') .gt. 0 .or.
      *    index(IntModel, 'nucrin') .gt. 0  .or.
      *    index(IntModel, 'dpmjet3') .gt. 0  .or.
      *    index(IntModel, 'incdpm3') .gt. 0  .or.
      *    index(IntModel, 'jam') .gt. 0  ) then
 
-c           for Lund init.  dpm may use Lund at low energy or
-c                                    for some particles
+!           for Lund init.  dpm may use Lund at low energy or
+!                                    for some particles
          call haddenC
          call chanwnC
       endif
@@ -156,7 +157,7 @@ c                                    for some particles
       endif
 
       if( index(IntModel, 'gheisha' ) .gt. 0) then
-c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
+!         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
          call gpart
          call gheini
       endif
@@ -177,12 +178,12 @@ c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
                call cinidpmjet(DpmFile)
             endif
          elseif(from .eq. 'check') then
-c           it is assumed that the Glauber file is
-c           specified by prefix/...GLB
+!           it is assumed that the Glauber file is
+!           specified by prefix/...GLB
 
          elseif(from == 'epics' .or. from == 'gencol') then
-c              dpmjet.inp is assumed in the same directory
-c              as config file.
+!              dpmjet.inp is assumed in the same directory
+!              as config file.
             call cformFullPath('dpmjet.inp', path)
             call cinidpmjet(path)
          else
@@ -199,27 +200,27 @@ c              as config file.
       call cerrorMsg(IntModel, 0)
       end
 
-c           
-c          next is for dpmjet file management.
-c          dpmfiles for Epcis is assumed to be in the
-c          same directory as config file resides so
-c          extract the directory where the config file is.
+!           
+!          next is for dpmjet file management.
+!          dpmfiles for Epcis is assumed to be in the
+!          same directory as config file resides so
+!          extract the directory where the config file is.
       subroutine cfixPrefix(dsn)
       implicit none
 #include "Zmanager.h"
       character*(*) dsn   ! input. config file name or path
-c            output. PrefixConf= './' or '/.../.../' where
-c                              config file exist.
-c                    PrefixLeng is it's length. 
-c      
-c
+!            output. PrefixConf= './' or '/.../.../' where
+!                              config file exist.
+!                    PrefixLeng is it's length. 
+!      
+!
       integer i, j, klena, k
 
       if( index(dsn, '/') .eq. 0 ) then
          PrefixConf = './'
          PrefixLeng = 2
       else
-c             find last '/'
+!             find last '/'
          i = klena(dsn)
          do j = i, 1, -1
             k = index(dsn(j:j), '/')
@@ -232,8 +233,8 @@ c             find last '/'
       endif
  33   continue
       end
-c         ***********  get Cosmos Top director
-c             and set it in TopDir in Zmanager.h
+!         ***********  get Cosmos Top director
+!             and set it in TopDir in Zmanager.h
       subroutine cgetTopDir
       implicit none
 #include "Zmanager.h"
@@ -277,28 +278,28 @@ c             and set it in TopDir in Zmanager.h
 
       end
       subroutine cputGencolCMS(cms)
-c           this is introduced for EPOS
-c     to save the single precision boost in EPOS
-c     call afinal is avoided to convert cms to lab
-c     conversion of which result becomes not accurate 
-c     if we convet it to cms again. (Gencol needs to do so)
-c
+!           this is introduced for EPOS
+!     to save the single precision boost in EPOS
+!     call afinal is avoided to convert cms to lab
+!     conversion of which result becomes not accurate 
+!     if we convet it to cms again. (Gencol needs to do so)
+!
       implicit none
 #include "Zptcl.h"
-      record /ptcl/ cms ! input. Gencol must
+      type(ptcl):: cms ! input. Gencol must
                       ! inform the cms (/n)
 
       common /forGencol/ cmsSave
-      record /ptcl/ cmsSave
+      type(ptcl):: cmsSave
       cmsSave = cms
       end
       subroutine cqGencolCMS(cms)
-c      ask gencol cms
-c
+!      ask gencol cms
+!
       implicit none
 #include "Zptcl.h"
-      record /ptcl/ cms  ! outut. 
+      type(ptcl):: cms  ! outut. 
       common /forGencol/ cmssave
-      record /ptcl/ cmsSave
+      type(ptcl):: cmsSave
       cms = cmsSave 
       end
