@@ -1,15 +1,15 @@
-c       sigma tot, inel, ela test
+!       sigma tot, inel, ela test
 #include "ZcosmosBD.h"
       program testxs
       implicit none      
-c #include "ZcosmosExt.h"
+! #include "ZcosmosExt.h"
 #include "Zcode.h"
 #include "Zptcl.h"
-c
-c
+!
+!
       real*8  p, A, Z, Ek, xsT, XsI, XsE, xsxpt, xsxpin
       integer code, subcode, charge, i
-      record /ptcl/ pj
+      type(ptcl):: pj
       write(0,*) 'enter proj code, subcode, charge'
       read(*,*)  code, subcode, charge
       write(0,*)' Enter A of target '
