@@ -1,17 +1,15 @@
 #!/bin/bash
 
 cat <<EOF
-a)  qgsjetII-04
+a)  qgsjetII-04  (LHC tuned)
 b)  qgsjetII-03
 Which model ? Enter a or b.
 EOF
 read ans
 if [ -z $ans ]; then
-    echo Enter a or  b
     exit
 fi
 source $COSMOSTOP/Scrpt/setarch.sh 
-#  echo "ARCH is " $ARCH
 
 if [ $ans == "a" ]; then
     echo "qgsjetII-04 is being made to be selectable"
