@@ -23,7 +23,7 @@ else
       done
       case  $num  in
       1)
-         (cd $1; rm -f `ls`) ;;
+         (cd $1; rm -fr `ls`) ;;
 #                      rm $1/*  dose no work here (why?)
       2)
         : ;;
@@ -33,4 +33,4 @@ else
     fi
 fi
 
-gawk -f $COSMOSTOP/Scrpt/splithisto.awk maindir=$1 $2
+awk -f $COSMOSTOP/Scrpt/splithisto.awk maindir=$1 $2
