@@ -3,8 +3,8 @@
 #include  "Zmagfield.h"
 #include  "Zearth.h"
       real*8 yearin, lat, long, height
-      record /coord/ llh
-      record /magfield/ h
+      type(coord):: llh
+      type(magfield):: h
       integer icon
                                   
       character*100 filepath
@@ -31,8 +31,8 @@
          call csetCoord('llh', lat, long, height, llh)
          call cgeomag(yearin, llh, h,  icon)
 
-         write(*,*)  ' icon=',icon, ' h.x,y,z=',h.x, h.y, h.z
-         write(*,*)  ' |B|=',sqrt(h.x**2 + h.y**2 + h.z**2)
+         write(*,*)  ' icon=',icon, ' h%x,y,z=',h%x, h%y, h%z
+         write(*,*)  ' |B|=',sqrt(h%x**2 + h%y**2 + h%z**2)
       enddo
 
       end
