@@ -1,12 +1,18 @@
-c      Compute magnetic deflection (angle and displacement)
-c      Use Runge-Kutta-Fehlberg Method.
-c      
-c     ************************************************  
+!      Compute magnetic deflection (angle and displacement)
+!      Use Runge-Kutta-Fehlberg Method.
+!      
+!     ************************************************  
+!>@brief Compute magnetic deflection (angle and displacement)
+!> Use Runge-Kutta-Fehlberg Method.
+!>@param[in] aTrack a charged ptcl (datatype /track/)
+!>@param[in] leng length travelled in m (datatype real*8)
+!>@param[out] newpos new position after leng move (datatype /coord/newpos)
+!>@param[out] newmom changed mon 
       subroutine cbDefByRK(aTrack, leng, newpos, newdir,newmom)
-c     ************************************************  
-c   This uses Runge-Kutta method with the automatically adjustable
-c   step size and takes a long time for execution.
-c
+!     ************************************************  
+!   This uses Runge-Kutta method with the automatically adjustable
+!   step size and takes a long time for execution.
+!
 
  
       implicit none
@@ -17,14 +23,14 @@ c
       real*8 geomcnst  !  Z/pc/3.3358. Z charge, pc GeV
       common /Zgeomcnst/ geomcnst
 
-      record /track/ aTrack       !input. a charged ptcl
+      type(track)::aTrack       !input. a charged ptcl
 
-c                              ptcl and magfiled coord is in Exyz
+!                              ptcl and magfiled coord is in Exyz
 
       real*8  leng                !input. length  travelled in m
 
-      record /coord/newpos      ! output. new position after leng move
-      record /coord/newdir      ! //      new direction cose. //
+      type(coord)::newpos      ! output. new position after leng move
+      type(coord)::newdir      ! //      new direction cose. //
 
       real*8  cbetat, x0
 
@@ -39,23 +45,24 @@ c                              ptcl and magfiled coord is in Exyz
       data first/1/, relaerr/1.d-2/, abserr/1.d3/
 
       cbetat= leng
-c       
-c      y0(1) = aTrack.pos.xyz.x
-c      y0(2) = aTrack.pos.xyz.y
-c      y0(3) = aTrack.pos.xyz.z
-c           IBM must be like below
-      y0(1) = aTrack.pos.xyz.r(1)
-      y0(2) = aTrack.pos.xyz.r(2)
-      y0(3) = aTrack.pos.xyz.r(3)
+!       
+!      y0(1) = aTrack.pos.xyz.x
+!      y0(2) = aTrack.pos.xyz.y
+!      y0(3) = aTrack.pos.xyz.z
+!           IBM must be like below
+      y0(1) = aTrack%pos%xyz%r(1)
+      y0(2) = aTrack%pos%xyz%r(2)
+      y0(3) = aTrack%pos%xyz%r(3)
       
-      y0(4)=  aTrack.vec.w.x
-      y0(5)=  aTrack.vec.w.y
-      y0(6)=  aTrack.vec.w.z
+!      y0(4)=  aTrack%vec%w%x
+!      y0(5)=  aTrack%vec%w%y
+!　    y0(6)=  aTrack%vec%w%z
+      y0(4:6) = aTrack%vec%w%r(1:3)
 
-c         pc in GeV
-      geomcnst = max(sqrt(aTrack.p.fm.p(4)**2- aTrack.p.mass**2), 1.d-9)
+!         pc in GeV
+      geomcnst = max(sqrt(aTrack%p%fm%p(4)**2- aTrack%p%mass**2), 1.d-9)
 
-      geomcnst = aTrack.p.charge/geomcnst/3.3358
+      geomcnst = aTrack%p%charge/geomcnst/3.3358
 
       x0= 0.d0   ! this cannot be a literal below; due to bad prog.
       call krungekutfds(6, cgeomfunc, x0, cbetat, y0, first, relaerr,
@@ -67,36 +74,36 @@ c         pc in GeV
          call  cbDefByRK2(aTrack, leng, newpos, newdir, newmom)
       else
 
-cc      first = 1
+!c      first = 1
 
-c      newpos.x = yn(1)
-c      newpos.y = yn(2)
-c      newpos.z = yn(3)
-c      for  ibm 
-         newpos.r(1) = yn(1)
-         newpos.r(2) = yn(2)
-         newpos.r(3) = yn(3)
-         newpos.sys='xyz'
-c      newdir.x = yn(4)
-c      newdir.y = yn(5)
-c      newdir.z = yn(6)
-c      for ibm
-         newdir.r(1) = yn(4)
-         newdir.r(2) = yn(5)
-         newdir.r(3) = yn(6)
+!      newpos.x = yn(1)
+!      newpos.y = yn(2)
+!      newpos.z = yn(3)
+!      for  ibm 
+         newpos%r(1) = yn(1)
+         newpos%r(2) = yn(2)
+         newpos%r(3) = yn(3)
+         newpos%sys='xyz'
+!      newdir.x = yn(4)
+!      newdir.y = yn(5)
+!      newdir.z = yn(6)
+!      for ibm
+         newdir%r(1) = yn(4)
+         newdir%r(2) = yn(5)
+         newdir%r(3) = yn(6)
 !               oh my god next yn(4:6)* sqrt(. ) was
 !                              yn(4:6)** sqrt(...)   !!!
 !             but default UseRungeKutta = 0 did not come here
          newmom(:) = yn(4:6)* 
-     *   sqrt(dot_product( aTrack.p.fm.p(1:3),aTrack.p.fm.p(1:3)))
-         newdir.sys='xyz'
+     *   sqrt(dot_product( aTrack%p%fm%p(1:3),aTrack%p%fm%p(1:3)))
+         newdir%sys='xyz'
       endif
       end
       subroutine cgeomfunc(L, y, f)
       implicit none
-c         this  is used both by cbDefByRK and cbDefByRK2
-c      Zobs.h is For Zobsp.h
-c      Zobsp.h is  For  YearOfGeomag
+!         this  is used both by cbDefByRK and cbDefByRK2
+!      Zobs.h is For Zobsp.h
+!      Zobsp.h is  For  YearOfGeomag
 #include "Zcoord.h"
 #include "Zmagfield.h"
 #include "Zobs.h"  
@@ -105,106 +112,106 @@ c      Zobsp.h is  For  YearOfGeomag
       real*8 geomcnst  !  Z/pc/3.3358. Z charge, pc GeV
       common /Zgeomcnst/ geomcnst
 
-      record /coord/ llh
-      record /magfield/ B
+      type(coord)::llh
+      type(magfield)::B
       integer icon
       real*8 L, y(6), f(6)
-c        L=cbetat is not used explicitly
+!        L=cbetat is not used explicitly
 
       f(1) = y(4)
       f(2) = y(5)
       f(3) = y(6)
-c          compute B at y(1),y(2), y(3)
-c
-c      llh.x = y(1)
-c      llh.y = y(2)
-c      llh.z = y(3)
-c        for ibm
-      llh.r(1) = y(1)
-      llh.r(2) = y(2)
-      llh.r(3) = y(3)
+!          compute B at y(1),y(2), y(3)
+!
+!      llh.x = y(1)
+!      llh.y = y(2)
+!      llh.z = y(3)
+!        for ibm
+      llh%r(1) = y(1)
+      llh%r(2) = y(2)
+      llh%r(3) = y(3)
 
-      llh.sys = 'xyz'   ! converted to 'llh' in cgeomag
+      llh%sys = 'xyz'   ! converted to 'llh' in cgeomag
       call cgeomag(YearOfGeomag, llh, B, icon)  ! B is ned
       call ctransMagTo('xyz', llh, B, B)        ! to xyx
-      f(4)= geomcnst * (y(5)*B.z - y(6)*B.y)
-      f(5) =geomcnst * (y(6)*B.x - y(4)*B.z)
-      f(6) =geomcnst * (y(4)*B.y - y(5)*B.x)
+      f(4)= geomcnst * (y(5)*B%z - y(6)*B%y)
+      f(5) =geomcnst * (y(6)*B%x - y(4)*B%z)
+      f(6) =geomcnst * (y(4)*B%y - y(5)*B%x)
       end
 
 
       subroutine krungekutfds(neq,func,x0,xe,y0,init,relerr,abserr,
      &                 yn,esterr,nde,ier,h,yl0,yln,err,work)
-c
-c        adapted from Maruzen Library.
-c
-**********************************************************************
-*     subroutine krungekutfds numerically integrates a system of neq *
-*     first order ordinary differential equations of the form        *
-*             dy(i)/dx = f(x, y(1),..., y(neq)),                     *
-*     by the runge-kutta-fehlberg (4,5) formula,                     *
-*     subroutine rkfds can detect the stiffness of the differential  *
-*     system.                                                        *
-*                                                                    *
-*     parameters                                                     *
-*  === input ===                                                     *
-*     (1) neq: number of equations to be integrated                  *
-*     (2) func: subroutine func(x,y,f) to evaluate derivatives       *
-*                f(i)=dy(i)/dx                                       *
-*     (3) x0: initial value of independent variable                  *
-*     (4) xe: output point at which the solution is desired          *
-*     (5) y0(i) (i=1,..,neq): initial value at x0                    *
-*     (6) init: indicator to initialize the code                     *
-*          init=1..the code will be initialized(first call).         *
-*          init=2..the code will not be initialized(subsequent call).*
-*     (7) relerr: relative local error tolerance                     *
-*     (8) abserr: absolute local error tolerance                     *
-*  === output ===                                                    *
-*     (9) yn(i) (i=1,..,neq): approximate solution at xe             *
-*    (10) esterr(i) (i=1,..,neq): estimate of the global error in    *
-*          the approximate solution yhn(i)                           *
-*    (11) nde: number of derivative evaluations                      *
-*    (12) ier: indicator for status of integration                   *
-*          ier=0..integration reached xe. indicates successful       *
-*             return and is the normal mode for continuing the       *
-*             integration.                                           *
-*          ier=10000..integration was not completed because too many *
-*             derivatives evaluations were needed.  if the user wants*
-*             to continue the integration, he just calls rkf again.  *
-*          ier=20000..integration was not completed because error    *
-*             tolerance was inappropriate(=it was zero).  must use   *
-*             non-zero abserr to continue the integration.           *
-*          ier=30000..integration was not completed because requested*
-*             accuracy could not be achieved using smallest stepsize.*
-*             must increase the error tolerance to continue the      *
-*             integration.                                           *
-*          ier=40000..integration was not completed because the      *
-*             stiffness of the differential system was detected.     *
-*             must use the subroutine, krsnat or krsat, which        *
-*             is designed to integrate stiff differential systems.   *
-*  === others ===                                                    *
-*    (13) h: variable to hold information internal to rkfds which is *
-*           necessary for subsequent calls.                          *
-*    (14) yl0(), yln(): array (size=neq) to hold information internal*
-*           to rkfds which is necessary for subsequent calls.        *
-*    (15) err(): array (size=neq) to be used inside rkfds            *
-*    (16) work(): two-dimentional array (size=(neq,12)) to be        *
-*                 used inside rkfds                                  *
-*    copyright: m. sugihara, november 15, 1989, v. 1                 *
-**********************************************************************
+!
+!        adapted from Maruzen Library.
+!
+!*********************************************************************
+!     subroutine krungekutfds numerically integrates a system of neq *
+!     first order ordinary differential equations of the form        *
+!             dy(i)/dx = f(x, y(1),..., y(neq)),                     *
+!     by the runge-kutta-fehlberg (4,5) formula,                     *
+!     subroutine rkfds can detect the stiffness of the differential  *
+!     system.                                                        *
+!                                                                    *
+!     parameters                                                     *
+!  === input ===                                                     *
+!     (1) neq: number of equations to be integrated                  *
+!     (2) func: subroutine func(x,y,f) to evaluate derivatives       *
+!                f(i)=dy(i)/dx                                       *
+!     (3) x0: initial value of independent variable                  *
+!     (4) xe: output point at which the solution is desired          *
+!     (5) y0(i) (i=1,..,neq): initial value at x0                    *
+!     (6) init: indicator to initialize the code                     *
+!          init=1..the code will be initialized(first call).         *
+!          init=2..the code will not be initialized(subsequent call).*
+!     (7) relerr: relative local error tolerance                     *
+!     (8) abserr: absolute local error tolerance                     *
+!  === output ===                                                    *
+!     (9) yn(i) (i=1,..,neq): approximate solution at xe             *
+!    (10) esterr(i) (i=1,..,neq): estimate of the global error in    *
+!          the approximate solution yhn(i)                           *
+!    (11) nde: number of derivative evaluations                      *
+!    (12) ier: indicator for status of integration                   *
+!          ier=0..integration reached xe. indicates successful       *
+!             return and is the normal mode for continuing the       *
+!             integration.                                           *
+!          ier=10000..integration was not completed because too many *
+!             derivatives evaluations were needed.  if the user wants*
+!             to continue the integration, he just calls rkf again.  *
+!          ier=20000..integration was not completed because error    *
+!             tolerance was inappropriate(=it was zero).  must use   *
+!             non-zero abserr to continue the integration.           *
+!          ier=30000..integration was not completed because requested*
+!             accuracy could not be achieved using smallest stepsize.*
+!             must increase the error tolerance to continue the      *
+!             integration.                                           *
+!          ier=40000..integration was not completed because the      *
+!             stiffness of the differential system was detected.     *
+!             must use the subroutine, krsnat or krsat, which        *
+!             is designed to integrate stiff differential systems.   *
+!  === others ===                                                    *
+!    (13) h: variable to hold information internal to rkfds which is *
+!           necessary for subsequent calls.                          *
+!    (14) yl0(), yln(): array (size=neq) to hold information internal*
+!           to rkfds which is necessary for subsequent calls.        *
+!    (15) err(): array (size=neq) to be used inside rkfds            *
+!    (16) work(): two-dimentional array (size=(neq,12)) to be        *
+!                 used inside rkfds                                  *
+!    copyright: m. sugihara, november 15, 1989, v. 1                 *
+!*********************************************************************
        implicit real*8(a-h,o-z)
        external func
        dimension y0(neq),yn(neq),esterr(neq),work(neq,12),
      &           yl0(neq),yln(neq),err(neq)
       call krungekutfs(neq,func,x0,xe,y0,init,relerr,abserr,
-c                  Next original one is wrong. //// corrected by K.K
-c     &          yn,esterr,nde,ier,h,yl0(neq),yln(neq),err(neq),
+!                  Next original one is wrong. //// corrected by K.K
+!     &          yn,esterr,nde,ier,h,yl0(neq),yln(neq),err(neq),
      &          yn,esterr,nde,ier,h, yl0, yln, err,
      &          work(1,1),work(1,2),work(1,3),work(1,4),work(1,5),
      &          work(1,6),work(1,7),work(1,8))
       return
       end
-c
+!
       subroutine krungekutfs(neq,func,x0,xe,yh0,init,relerr,abserr,
      &               yhn,esterr,nde,ier,h,yl0,yln,err,
      &               ak1,ak2,ak3,ak4,ak5,ak6,et,work)
@@ -218,13 +225,13 @@ c
      &           err(neq),et(neq),work(neq,5)
        data itemax / 100000 /
        data epsmin / 1.0d-15 /
-c
+!
       if (init .eq. 1) then
-c -------------- initialization (first call)-------------------------
+! -------------- initialization (first call)-------------------------
        do 10 i = 1,neq
         yl0(i) = yh0(i)
    10  continue
-c      -------- set initial step size --------
+!      -------- set initial step size --------
 
        call func(x0,yl0,ak1)
        toldy = 10.0d+74
@@ -240,19 +247,19 @@ c      -------- set initial step size --------
        else
         h = min((xe - x0) / 100.0d+0, toldy ** 0.2d+0)
        end if
-c     ----------------------------------------
+!     ----------------------------------------
        init = 2
        nde = 1
       else
        nde = 0
       endif
-c -------------------------------------------------------------------
+! -------------------------------------------------------------------
       istiff = 0
       icount = 0
       ier = 0
       x = x0
-c
-*********************** main iteration *********************************
+!
+!********************** main iteration *********************************
       do 30 iter = 1,itemax
        call krkflstep(neq,func,x,h,yl0,yln,ak1,ak2,ak3,ak4,ak5,
      &             ak6,err,work)
@@ -267,7 +274,7 @@ c
         end if
    40  continue
        if (erret .ge. 1.0d+0) then
-c--------------- unsuccessful step ------------------------------
+!--------------- unsuccessful step ------------------------------
         if (erret .ge. 59049.0d+0) then
          h = 0.1d+0 * h
         else
@@ -275,8 +282,8 @@ c--------------- unsuccessful step ------------------------------
         end if
          if (h .le. epsmin) go to 30000
        else if ((x + h) .lt. xe) then
-c-------------- successful step (x + h < the end point)------------
-c       ********* routine for detecting stiffness *********
+!-------------- successful step (x + h < the end point)------------
+!       ********* routine for detecting stiffness *********
         icount = icount + 1
         erretl = 0.0d+0
         do 100 i = 1,neq
@@ -287,14 +294,14 @@ c       ********* routine for detecting stiffness *********
         if (erretl .le. 1.0d+0) istiff = istiff + 1
         if (icount .eq. 50) then
          if (istiff .ge. 25) then
-c       ------ stiffness was detected ------
+!       ------ stiffness was detected ------
           go to 40000
          else
           icount = 0
           istiff = 0
          end if
         end if
-c       **************************************************
+!       **************************************************
 
         call krkfhstep(neq,func,x,h,yh0,yhn,ak1,ak2,ak3,ak4,ak5,
      &              ak6,err,work)
@@ -307,15 +314,15 @@ c       **************************************************
          yh0(i) = yhn(i)
    50   continue
 
-c       ------- choose next step -----------
-        if (erret.le.1.889568d-4) then
+!       ------- choose next step -----------
+        if (erret .le. 1.889568d-4) then
          h = 5.0d+0 * h
         else
          h = 0.9d+0 * h / (erret ** 0.2d+0)
         end if
-c       ------------------------------------
+!       ------------------------------------
        else
-c-------------- successful step (x + h > = the end point) --------------
+!-------------- successful step (x + h > = the end point) --------------
         h = xe-x
         call krkflstep(neq,func,x,h,yl0,yln,ak1,ak2,ak3,ak4,ak5,
      &              ak6,err,work)
@@ -323,11 +330,11 @@ c-------------- successful step (x + h > = the end point) --------------
      &              ak6,err,work)
 
         nde = nde + 18
-c      -------- estimate global error ----------
+!      -------- estimate global error ----------
         do 60 i = 1,neq
          esterr(i) = (yln(i) - yhn(i)) / 31.0d+0
    60   continue
-c      -----------------------------------------
+!      -----------------------------------------
         x0 = xe
         do 70 i = 1,neq
          yl0(i) = yln(i)
@@ -336,8 +343,8 @@ c      -----------------------------------------
         return
        endif
    30 continue
-**********************************************************************
-c
+!*********************************************************************
+!
       ier = 10000
       write( * ,10001) x
 10001 format(' ','(subr.-rkfds) trouble(too many iterations))',
@@ -364,7 +371,7 @@ c
      &,' is recommened.'
       return
       end
-c
+!
       subroutine krkflstep(neq,func,x,h,y0,yn,ak1,ak2,ak3,ak4,ak5,ak6,
      &                  err,work)
        implicit real*8(a-h,o-z)
@@ -377,7 +384,7 @@ c
 
       return
       end
-c
+!
       subroutine krkfhstep(neq,func,x,h,y0,yn,ak1,ak2,ak3,ak4,ak5,ak6,
      &                  err,work)
        implicit real*8(a-h,o-z)
@@ -398,7 +405,7 @@ c
      &          err,work(1,1),work(1,2),work(1,3),work(1,4),work(1,5))
       return
       end
-c
+!
       subroutine krkfehl(lindex,neq,func,x,h,y0,yn,ak1,ak2,ak3,ak4,ak5,
      &                ak6,err,w2,w3,w4,w5,w6)
        implicit real*8(a-h,o-z)
@@ -458,15 +465,15 @@ c
    70  continue
       endif
       end
-c      Compute magnetic deflection (angle and displacement)
-c      Use Runge-Kutta-Fehlberg Method.
-c      
-c     ************************************************  
+!      Compute magnetic deflection (angle and displacement)
+!      Use Runge-Kutta-Fehlberg Method.
+!      
+!     ************************************************  
       subroutine cbDefByRK2(aTrack, leng, newpos, newdir, newmom)
-c     ************************************************  
-c   This used Runge-Kutta-Gill  method. The step size
-c   is fixed.
-c
+!     ************************************************  
+!   This used Runge-Kutta-Gill  method. The step size
+!   is fixed.
+!
  
       implicit none
 
@@ -475,17 +482,17 @@ c
       real*8 geomcnst  !  Z/pc/3.3358. Z charge, pc GeV
       common /Zgeomcnst/ geomcnst
 
-      record /track/ aTrack       !input. a charged ptcl
+      type(track)::aTrack       !input. a charged ptcl
 
-c                              ptcl and magfiled coord is in Exyz
+!                              ptcl and magfiled coord is in Exyz
 
       real*8  leng            !input. length  travelled in m
                      ! since we use Ruuge-Kutta-Gill method with fixed
                      ! step size, we use leng/2  as the step size assuming
                      !  leng is (Larmor radius)/5. 
 
-      record /coord/newpos      ! output. new position after leng move
-      record /coord/newdir      ! //      new direction cose. //
+      type(coord)::newpos      ! output. new position after leng move
+      type(coord)::newdir      ! //      new direction cose. //
 
       real*8  cbetat, x0
 
@@ -499,19 +506,21 @@ c                              ptcl and magfiled coord is in Exyz
 
 
       cbetat= leng/(m-1)
-c       
-      y0(1) = aTrack.pos.xyz.x
-      y0(2) = aTrack.pos.xyz.y
-      y0(3) = aTrack.pos.xyz.z
+!       
+!      y0(1) = aTrack.pos.xyz.x
+!      y0(2) = aTrack.pos.xyz.y
+!     y0(3) = aTrack.pos.xyz.z
+       y0(1:3) = aTrack%pos%xyz%r(1:3)
       
-      y0(4)=  aTrack.vec.w.x
-      y0(5)=  aTrack.vec.w.y
-      y0(6)=  aTrack.vec.w.z
+!      y0(4)=  aTrack%vec%w%x
+!      y0(5)=  aTrack%vec%w%y
+!      y0(6)=  aTrack%vec%w%z
+       y0(4:6) = aTrack%vec%w%r(1:3) 
 
-c         pc in GeV
-      geomcnst = max(sqrt(aTrack.p.fm.p(4)**2- aTrack.p.mass**2), 1.d-9)
+!         pc in GeV
+      geomcnst = max(sqrt(aTrack%p%fm%p(4)**2- aTrack%p%mass**2), 1.d-9)
 
-      geomcnst = aTrack.p.charge/geomcnst/3.3358
+      geomcnst = aTrack%p%charge/geomcnst/3.3358
 
       x0 = 0.d0
       call krungeKutG(cgeomfunc, 6,  x0, y0, m, cbetat, 6,  y, wk, ier)
@@ -520,32 +529,32 @@ c         pc in GeV
       endif
 
 
-c      newpos.x = y(1,m)
-c      newpos.y = y(2,m)
-c      newpos.z = y(3,m)
-c       for ibm
-       newpos.r(1) = y(1,m)
-       newpos.r(2) = y(2,m)
-       newpos.r(3) = y(3,m)
-       newpos.sys='xyz'
-c      newdir.r(1) = y(4,m)
-c      newdir.r(2) = y(5,m)
-c      newdir.r(3) = y(6,m)
-c          for ibm
-      newdir.r(1) = y(4,m)
-      newdir.r(2) = y(5,m)
-      newdir.r(3) = y(6,m)
+!      newpos.x = y(1,m)
+!      newpos.y = y(2,m)
+!      newpos.z = y(3,m)
+!       for ibm
+       newpos%r(1) = y(1,m)
+       newpos%r(2) = y(2,m)
+       newpos%r(3) = y(3,m)
+       newpos%sys='xyz'
+!      newdir.r(1) = y(4,m)
+!      newdir.r(2) = y(5,m)
+!      newdir.r(3) = y(6,m)
+!          for ibm
+      newdir%r(1) = y(4,m)
+      newdir%r(2) = y(5,m)
+      newdir%r(3) = y(6,m)
       newmom(:) = y(4:6,m)*
-     * sqrt( dot_product(aTrack.p.fm.p(1:3),aTrack.p.fm.p(1:3)) )
-      newdir.sys='xyz'
+     * sqrt( dot_product(aTrack%p%fm%p(1:3),aTrack%p%fm%p(1:3)) )
+      newdir%sys='xyz'
       end
-c     *********************************************************
-c      Runge-Kutta-Gill method.
+!     *********************************************************
+!      Runge-Kutta-Gill method.
       subroutine krungeKutG(func, n, x0, y0, m, h, ny, y, wk, ierr)
       implicit none
-c
-c  solvoes n sets of dy/dx = f(x,y) 
-c
+!
+!  solvoes n sets of dy/dx = f(x,y) 
+!
       external func  ! input.   func is a external subroutine name
       integer  n     ! input.   number of defferential equations
       real*8 x0      !  input. initial value.
@@ -560,9 +569,9 @@ c
       integer  ierr  !  output. condition code. 
                      !  0 ,no error was detected.
                      !  1  n<1, n> ny, m<2 
-c        the structure of  func is the same as for krungekutfds.
-c-----------------------------------------------------------------------
-c
+!        the structure of  func is the same as for krungekutfds.
+!-----------------------------------------------------------------------
+!
       real*8  zero, half, two, three, const, six
       integer k, i
       real*8 t2, t3, x
@@ -627,13 +636,13 @@ c
          enddo
       endif
       end
-c     ************************************************  
+!     ************************************************  
       subroutine cbDefUser(aTrack, leng, newpos, newdir,newmom )
-c     ************************************************  
-c    
-c      another method to get the new position  and direction
-c      cosines when magnetic field exists.
-c  This is called when UseRungeKutta is 8.
+!     ************************************************  
+!    
+!      another method to get the new position  and direction
+!      cosines when magnetic field exists.
+!  This is called when UseRungeKutta is 8.
  
       implicit none
 
@@ -643,49 +652,49 @@ c  This is called when UseRungeKutta is 8.
       real*8 geomcnst  !  Z/pc/3.3358. Z charge, pc GeV
       common /Zgeomcnst/ geomcnst
 
-      record /track/ aTrack   ! input. a charged ptcl
+      type(track)::aTrack   ! input. a charged ptcl
       real(8),intent(out):: newmom ! changed momentum
-c     
-c        current position
-c            aTrack.pos.xyz.x, aTrack.pos.xyz.y, aTrack.pos.xyz.z (m)
-c        current direction cosines
-c            aTrack.vec.w.x,  aTrack.vec.w.y,  aTrack.vec.w.z
-c        current momentum,  total energy (GeV)
-c            aTrack.p.fm.p(i) i=1,4
-c        mass                  patcl code      subcode           charge
-c            aTrack.p.mass   aTrack.p.code  aTrack.p.subcode,aTrack.p.charge
-c   if code = kgnuc (isotope), subcode has mass number.
-c
+!     
+!        current position
+!            aTrack.pos.xyz.x, aTrack.pos.xyz.y, aTrack.pos.xyz.z (m)
+!        current direction cosines
+!            aTrack.vec.w.x,  aTrack.vec.w.y,  aTrack.vec.w.z
+!        current momentum,  total energy (GeV)
+!            aTrack.p.fm.p(i) i=1,4
+!        mass                  patcl code      subcode           charge
+!            aTrack.p.mass   aTrack.p.code  aTrack.p.subcode,aTrack.p.charge
+!   if code = kgnuc (isotope), subcode has mass number.
+!
 
              
 
-c               ptcl and magfiled coord is in Exyz
+!               ptcl and magfiled coord is in Exyz
 
       real*8  leng   ! input. length  travelled in m
 
-      record /coord/newpos  ! output. new position after moving leng (m)
+      type(coord)::newpos  ! output. new position after moving leng (m)
                             !
                             !   newpos.x newpos.y, newpos.z must be given
                             !   newpos.sys='xyz' must be gieven
-      record /coord/newdir  ! //      new direction cose. //
+      type(coord)::newdir  ! //      new direction cose. //
                             !   newdir.x, newdir.y, newdir.z must be given
                             !   newdir.sys='xyz' must be given
 
-c         pc in GeV
-      geomcnst = max(sqrt(aTrack.p.fm.p(4)**2- aTrack.p.mass**2), 1.d-9)
-      geomcnst = aTrack.p.charge/geomcnst/3.3358
-cc
-cc      You may see cgeomfunc how to get magnetic field etc
-cc
-c       Note:  cgeomag routine below gives B in north, east, down
-c              coordinate system, so that it must be converted into
-c              E-xyz system by calling ctransMagTo like below.
-c
-c      call cgeomag(YearOfGeomag, llh, B, icon)  ! B is ned
-c      call ctransMagTo('xyz', llh, B, B)        ! to xyx
-c
+!         pc in GeV
+      geomcnst = max(sqrt(aTrack%p%fm%p(4)**2- aTrack%p%mass**2), 1.d-9)
+      geomcnst = aTrack%p%charge/geomcnst/3.3358
+!c
+!c      You may see cgeomfunc how to get magnetic field etc
+!c
+!       Note:  cgeomag routine below gives B in north, east, down
+!              coordinate system, so that it must be converted into
+!              E-xyz system by calling ctransMagTo like below.
+!
+!      call cgeomag(YearOfGeomag, llh, B, icon)  ! B is ned
+!      call ctransMagTo('xyz', llh, B, B)        ! to xyx
+!
 
-      newpos.sys = 'xyz'
-      newdir.sys = 'xyz'
+      newpos%sys = 'xyz'
+      newdir%sys = 'xyz'
       end
 
