@@ -15,8 +15,8 @@
       elseif(Trace .gt. 60  .and. Trace .lt. 100) then
          call cputCerenkovE     ! cerenkov output trailer
       endif
-c                                               for each event
-c         get size weighted age
+!                                               for each event
+!         get size weighted age
       dvlpd = .false.
       if(ObserveAS) then
          if(Upgoing) then   ! upgoing primary
@@ -29,13 +29,13 @@ c         get size weighted age
             is = 1
          endif
          do i = ib, ie, is
-            if(ASObsSites(i).esize .gt. 0.) then
+            if(ASObsSites(i)%esize .gt. 0.) then
                dvlpd = .true.
-               ASObsSites(i).age = ASObsSites(i).age/ASObsSites(i).esize
+               ASObsSites(i)%age = ASObsSites(i)%age/ASObsSites(i)%esize
             elseif(dvlpd) then
-               ASObsSites(i).age = 5.0    ! died out.
+               ASObsSites(i)%age = 5.0    ! died out.
             else
-               ASObsSites(i).age = 0.0   ! not yet developed
+               ASObsSites(i)%age = 0.0   ! not yet developed
             endif
          enddo
       endif
