@@ -1,9 +1,9 @@
-c        csampGIntL:  sample photon interaction length.
+!        csampGIntL:  sample photon interaction length.
        subroutine csampGIntL
        use modXsecMedia
-c
-c        pair, compton, photo-electric eff. photo-hadron
-c
+!
+!        pair, compton, photo-electric eff. photo-hadron
+!
        implicit none
 #include  "Zglobalc.h"
 #include  "Ztrack.h"
@@ -12,33 +12,33 @@ c
 #include  "Zevhnv.h"
 #include  "Zelemagp.h"
 
-c
+!
 
        real*8  t, tkgpm2, cxai, den, cvh2den, eg
        real*8  prob, u, cmPairMFP, mfp, xs
        real*8  tcomp, tphot, tpair, tgp, tcoh
        real*8 xprob(5), txray(5)
             
-       real*4  xsec(5)  !  coh, incoh,  P.E  1/(g/cm2)  
+       real*4  xsec(5)  !  coh, incoh,  P%E  1/(g/cm2)  
        real*8 xaimin/0.1/
-c////////////////
+!////////////////
        integer,save::nzero=0
-c/////////////
-c     
-       eg = TrackBefMove.p.fm.p(4)
+!/////////////
+!     
+       eg = TrackBefMove%p%fm%p(4)
        if(LpmEffect .and. eg .gt. LpmPairEmin) then
-c          den = cthick2den(TrackBefMove.pos.depth)
-          den = cvh2den(TrackBefMove.pos.height)  ! better
+!          den = cthick2den(TrackBefMove.pos.depth)
+          den = cvh2den(TrackBefMove%pos%height)  ! better
           call cpairLPMXsec(eg, den, prob)
           call rndc(u)
           t = -log(u) /prob
        elseif( eg .gt. 1.022d-3 ) then
           if(eg .le. Excom2 ) then
              call cXrayp(eg, 4, 5,  xprob, txray)
-             prob= xprob(4)+xprob(5)  !  1/r.l
+             prob= xprob(4)+xprob(5)  !  1/r%l
              if( prob > 0. ) then
                 call rndc(u)
-                t = -log(u)/prob !  r.l
+                t = -log(u)/prob !  r%l
              else
                 call cpairPath(eg, t)
              endif
@@ -51,7 +51,7 @@ c          den = cthick2den(TrackBefMove.pos.depth)
        call csetIntInf(t*X0, .false., 'pair')
 
        if(eg .le. Excom1 )  then
-c           use Xcom data
+!           use Xcom data
           call cXrayp(eg,  1, 3,  xprob, txray)
           call csetIntInf(txray(2)*X0, .false., 'compt')
           call csetIntInf(txray(3)*X0, .false., 'photoe')
@@ -68,9 +68,9 @@ c           use Xcom data
              call csetIntInf(t*X0, .false., 'photoe')
           endif
        endif
-c           photo hadron prod.
+!           photo hadron prod.
        if( eg .gt. MinPhotoProdE .and. HowPhotoP > 0 ) then
-          call cgetPhotoPxs(ActiveMdl2, TrackBefMove.p,
+          call cgetPhotoPxs(ActiveMdl2, TrackBefMove%p,
      *       media(1), xs, mfp)    ! xs in mb. mfp in kg/m2
           call rndc(u)
           tkgpm2 = -mfp*log(u)
@@ -78,9 +78,9 @@ c           photo hadron prod.
           call csetIntInf(tkgpm2, .false., 'photop')
        endif
 
-c           magnetic  pair
+!           magnetic  pair
        if(MagPair .eq. 1 .and. eg .gt.  MagPairEmin) then
-          Xai = cxai(TrackBefMove.p, Mag)
+          Xai = cxai(TrackBefMove%p, Mag)
           if(Xai .gt. xaimin) then
              call rndc(u)
              t = -log(u) * cmPairMFP(eg, Xai)
