@@ -2,14 +2,14 @@
       implicit none
 #include  "Zptcl.h"
 #include  "Zcode.h"
-       record /ptcl/ p
+       type(ptcl):: p
        integer code
-c                set parent particle code by using last bit
-c                      bit 2    bit 1
-c                 pi    0         0
-c                 K     0         1
-c                 p     1         0
-c             pbar/nbar 1         1 
+!                set parent particle code by using last bit
+!                      bit 2    bit 1
+!                 pi    0         0
+!                 K     0         1
+!                 p     1         0
+!             pbar/nbar 1         1 
        if( p.code .eq. 4 ) then
           call krsetbit(code, 1)
           call krsetbit(code, 2)
