@@ -16,16 +16,16 @@
 #include "Zprivate2.h"
 #include "../Zabsorb.h"
       integer id  ! input.  1 ==> aTrack is going out from
-c                                 outer boundery.
-c                           2 ==> reached at an observation level
-c                           3 ==> reached at inner boundery.
-      record /track/ aTrack
+!                                 outer boundery.
+!                           2 ==> reached at an observation level
+!                           3 ==> reached at inner boundery.
+      type(track):: aTrack
 
-c      record /track/ inci
-c////////////
-      record /coord/ pdir, cdir
-c////////////
-      record /coord/ tetafai
+!      type(track):: inci
+!////////////
+      type(coord):: pdir, cdir
+!////////////
+      type(coord):: tetafai
       
       character*128 input
       character*64 dirstr
@@ -53,7 +53,7 @@ c////////////
       real*8  cvh2den
       data BinFai/30./
       integer ldep
-c     integer ndummy
+!     integer ndummy
       character*9 ptcln(4)
       data ptcln/"Photons", "Electrons","Muons", "hadron"/
       character*9 ptcl2(3)
@@ -78,9 +78,9 @@ c     integer ndummy
       integer vn/2/ ! version number for the fnoB output
       save 
 
-c     ***********************
+!     ***********************
       include "interface1.h"
-c     *********************
+!     *********************
 
 
       do i = 1, nsites
@@ -88,7 +88,7 @@ c     *********************
       enddo
 
       do i = 1, nsites
-c             histdep(i) is the layer number
+!             histdep(i) is the layer number
          if(histdep(i) .eq. 0)  exit
          ansites = i
          w2hl( histdep(i) ) = i
@@ -98,22 +98,22 @@ c             histdep(i) is the layer number
       dr = 10.**bin 
 
       do i = 1, nrbin
-c            center of the bin:   
+!            center of the bin:   
          rbin(i) = r
          r = r* dr
       enddo
 #if defined (MACOSX)
 #else
-c            specify bin or ascii output
+!            specify bin or ascii output
       call kwhistso( binw )
 #endif
 
       return      
-c     *********************************** hook for Beginning of  1 event
-c     *  All system-level initialization for 1 event generation has been
-c     *  eneded at this moment.
-c     *  After this is executed, event generation starts.
-c     *
+!     *********************************** hook for Beginning of  1 event
+!     *  All system-level initialization for 1 event generation has been
+!     *  eneded at this moment.
+!     *  After this is executed, event generation starts.
+!     *
       entry xBgEvent
 
       call cqIncident(inci, angle)
@@ -150,15 +150,15 @@ c     *
          do ifai = 1, nfai
             do ir= 1, nrbin
                dErfai(ir, ifai, i) = 0.
-c               do j = 1, 4
-c                  nrfaiAll(ir, ifai, j, i) = 0.
-c               enddo
+!               do j = 1, 4
+!                  nrfaiAll(ir, ifai, j, i) = 0.
+!               enddo
             enddo
          enddo
       enddo
 
 
-c          estimate time minimum and time bin for eeach web sector
+!          estimate time minimum and time bin for eeach web sector
       
       do i = 1, ansites
          ldep = histdep(i)
@@ -168,18 +168,18 @@ c          estimate time minimum and time bin for eeach web sector
 
 #if defined (MACOSX)
 #else
-c     histogram: instanciate
-c           t spectrum at each web sector
+!     histogram: instanciate
+!           t spectrum at each web sector
       if(tkrtspec) then
          do i = 1, ansites
             do j = 1, 4
-c                at  center
+!                at  center
                call kwhisti( tspec0(j, i),
      *          -5., 0.05, 200, b'00000')
                call kwhistai( tspec0(j, i),
      *         "Arrival time dist. of "//ptcln(j)//" at center",
      *         "t", "ptcls", .false., 0., "time", "ns")
-c                   clear
+!                   clear
                call kwhistc(tspec0(j, i))
 
                do ir=1, nrbin
@@ -202,7 +202,7 @@ c                   clear
                      call kwhistai( tspec(j, ir, ifai,  i),
      *                "Arrival time of "//ptcln(j)//" at (r,fai)",
      *                "rt", "ptcls", .false., 0., "time", "ns")
-c                     clear 
+!                     clear 
                      call kwhistc(tspec(j, ir, ifai, i))
                   enddo
                enddo
@@ -210,7 +210,7 @@ c                     clear
          enddo
       endif
 
-c            lateral in each fai bin
+!            lateral in each fai bin
       if(tkarspec) then
 
          do i = 1, ansites
@@ -221,7 +221,7 @@ c            lateral in each fai bin
                   call kwhistai(rspec(j, ifai, i), 
      *            "Lateral Dist. of "//ptcln(j)//" at  diff. azimuth",
      *            "ar", "ptcls", .true.,  power(j),   "r", "m.u")
-c                     clear
+!                     clear
                   call  kwhistc( rspec(j, ifai, i) )
                enddo
             enddo
@@ -232,12 +232,12 @@ c                     clear
       obstimes = 0.
 
       return
-c     ***************
+!     ***************
       entry xObs(aTrack, id)
-c
-c     For id =2, you need not output the z value, because it is always
-c     0 (within the computational accuracy).
-c
+!
+!     For id =2, you need not output the z value, because it is always
+!     0 (within the computational accuracy).
+!
       obstimes = obstimes + 1.d0
       if(mod(obstimes, 100000.d0) .eq. 0. ) then 
          dosort=.false.
@@ -255,10 +255,10 @@ c
             write(0,*)' stack tops=', Stack(i).p.fm.p(4)
          enddo
       endif
-c     ***************
+!     ***************
       code = aTrack.p.code
       ldep =  aTrack.where
-c     ************
+!     ************
       if(id .eq. 2 .and. code .le. 6 ) then  ! neglect rare ptcls
          wz = aTrack.vec.w.r(3) ! downgoing < 0
          if(wz .gt. 0) return
@@ -281,33 +281,33 @@ c     ************
          elseif(code .le. 6) then
             Nhad(ldep) = Nhad(ldep) +aTrack.wgt
          endif
-c            ---------- compute energy loss 
+!            ---------- compute energy loss 
          if(aTrack.p.charge .ne. 0  ) then
-c             -----------------
-c                      /|    |
-c                     / |   1g/cm2 
-c                    /A |    |
-c            -------------------
-c                  / ptcl direction  
-c         get energy loss when aTrack goes some distance
-c         of which vertical gramage is 1g/cm2.
-c         Gramage the particle travel is 
-c         1/cos where cos is the cos of angle (i.e, A if Fig)
-c          in the detctor system.
-c         1g/cm^2 = 10-3kg/10-4 m^2 =10 kg/m^2.
-c         To travel  1 g/cm^2, the ptcl must
-c         run dist kg/m^2
+!             -----------------
+!                      /|    |
+!                     / |   1g/cm2 
+!                    /A |    |
+!            -------------------
+!                  / ptcl direction  
+!         get energy loss when aTrack goes some distance
+!         of which vertical gramage is 1g/cm2.
+!         Gramage the particle travel is 
+!         1/cos where cos is the cos of angle (i.e, A if Fig)
+!          in the detctor system.
+!         1g/cm^2 = 10-3kg/10-4 m^2 =10 kg/m^2.
+!         To travel  1 g/cm^2, the ptcl must
+!         run dist kg/m^2
             if(abs(wz) .gt. 1.d-2) then
                dist =10./wz    ! in kg/m2/(g/cm2)
             else
-c                 for safety
+!                 for safety
                dist =1000.
             endif
 
             call cqElossRate(dedt,dedtF) !  loss rate GeV/(kg/m^2)
-c                     dedtF is the full eloss ; dedt is the restricted
-c                     loss.  We may better use full here.
-c                       energy in 1 g/cm2 of vertical direction
+!                     dedtF is the full eloss ; dedt is the restricted
+!                     loss.  We may better use full here.
+!                       energy in 1 g/cm2 of vertical direction
             Eloss =min( real(dedtF*dist), Ek)   !  GeV/(g/cm2)
             Eloss = Eloss*aTrack.wgt !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
@@ -318,8 +318,8 @@ c                       energy in 1 g/cm2 of vertical direction
          if(code .ge. 4) code=4
          if( aTrack.p.charge .ne. 0   .or. 
      *       w2hl(ldep) .gt. 0 ) then 
-c                  fai
-c              fai is  in    -15 to 345  (for dfai=30.)                                     
+!                  fai
+!              fai is  in    -15 to 345  (for dfai=30.)                                     
             aa=atan2(aTrack.pos.xyz.y, aTrack.pos.xyz.x)*
      *        Todeg -fai0
             fai = aa/Todeg
@@ -332,9 +332,9 @@ c              fai is  in    -15 to 345  (for dfai=30.)
             elseif(ridx .le. 0) then
                dECent(ldep) = dECent(ldep) + Eloss
             endif
-c 
-c  do following   for specified histo layers (typically only 1 layer)
-c
+! 
+!  do following   for specified histo layers (typically only 1 layer)
+!
 #if defined  (MACOSX)
 #else
             if( w2hl(ldep)  .gt. 0 ) then
@@ -364,15 +364,15 @@ c
          endif
       endif
       return
-c     **************
+!     **************
       entry xEnEvent
-c     **************
-c        replace  @ # % in basefilename by hostname, etc
-c        and put it in basefilename2
-c        
-c////////////
-c      call sleep(1)
-c///////////////
+!     **************
+!        replace  @ # % in basefilename by hostname, etc
+!        and put it in basefilename2
+!        
+!////////////
+!      call sleep(1)
+!///////////////
       
       write(0,*) 'ev#=',EventNo,
      *   ' generation phase finished. now writing data'
@@ -398,7 +398,7 @@ c///////////////
             cog = cog + ASObsSites(i).esize*dd*ASDepthList(i)
             sumne= sumne +ASObsSites(i).esize*dd
          enddo
-c          0.1 is for g/cm2
+!          0.1 is for g/cm2
          cog = cog*0.1/sumne
 
          cog2 = 0.
@@ -422,7 +422,7 @@ c          0.1 is for g/cm2
          if(sumne .gt. 0.) then
             cog2 = cog2*0.1/sumne
          else
-c              to deep penetration
+!              to deep penetration
             cog2 = ASDepthList(NoOfASSites)*0.1
          endif
 
@@ -460,13 +460,13 @@ c              to deep penetration
      *          Ng(i), Ne(i), Nmu(i), Nhad(i),
      *          ASObsSites(i).esize, SumEloss(i), 
      *          dEbydEdx(i), dEbyDeath(i), 
-c                   next ones are from 7.51
+!                   next ones are from 7.51
      *          dEbyDeathG(i),  dEbyDeathE(i), dEbyDeathMuPiK(i), 
      *          dEbyDeathP(i),  dEbyDeathNut(i), dEbyDeathO(i)
 
                if(i .le. Eabsorb(2) ) then
-c                    to see E consv. we should not count
-c                    level > Eabsorb(2).
+!                    to see E consv. we should not count
+!                    level > Eabsorb(2).
                   sumEbydEdx = sumEbydEdx + dEbydEdx(i)
                   sumEbyDeath = sumEbyDeath + dEbyDeath(i)
                   sumEbyDeathNeu = sumEbyDeathNeu +dEbyDeathNeu(i)
@@ -513,11 +513,11 @@ c                    level > Eabsorb(2).
 
             write(fnoB,'("r ", 1p4E11.3)') 
      *      sumdEinAir/E0, sumUncertain/E0, sumMissing/E0, sumAll/E0
-c                normalized one
+!                normalized one
             write(fnoB,'("n ", 1p4E11.3)') 
      *      sumdEinAir/sumAll, sumUncertain/sumAll,sumMissing/sumAll,
      *      1.0
-c                additional info for more details
+!                additional info for more details
             write(fnoB,'("a ", 1p5g12.3 )')
      *      sumEbyDeathG,  sumEbyDeathE,  sumEbyDeathMuPiK,
      *      sumEbyDeathP,  sumEbyDeathO
@@ -548,12 +548,12 @@ c                additional info for more details
                call kseblk(dirstr, "|", nstr)
                do l = 1, nfai
                   call kwhistdir(rspec(j, l,  i),  dirstr)
-c                  call kwhists(  rspec(j, l, i), 0. )
+!                  call kwhists(  rspec(j, l, i), 0. )
                   call kwhists(  rspec(j, l, i), 0. )
                   call kwhistev( rspec(j, l, i), EventNo)
                   call kwhistid( rspec(j, l,  i), evid(i))
                   call kwhistp( rspec(j, l, i),  fnoL)
-c                        *********** deallocate ********                            
+!                        *********** deallocate ********                            
                   call kwhistd( rspec(j, l, i) )
                enddo  ! code loop                                                   
             enddo ! fai loop                                                        
@@ -578,7 +578,7 @@ c                        *********** deallocate ********
                call kseblk( dirstr, "|", nstr)
                call kwhistdir( tspec0(j,i),  dirstr )
                call kwhistp( tspec0(j,i),  fnoT )
-c                 *********** deallocate ********         
+!                 *********** deallocate ********         
                call kwhistd( tspec0(j,i) )
             enddo
          enddo
@@ -596,7 +596,7 @@ c                 *********** deallocate ********
                      call kseblk(dirstr, "|", nstr)
                      call kwhistdir(tspec(j,ir, ifai,i),  dirstr)
                      call kwhistp( tspec(j,ir, ifai,i),  fnoT)
-c                        *********** deallocate ********                            
+!                        *********** deallocate ********                            
                      call kwhistd( tspec(j, ir, ifai, i) )
                   enddo
                enddo
@@ -605,7 +605,7 @@ c                        *********** deallocate ********
          close(fnoT)
       endif
 #endif
-c          output web data
+!          output web data
       if(tkweb) then
          filename = basefilename2(1:klena(basefilename2))//".nrfai"
          call copenfw2(fnoN, filename, 1, icon)
@@ -614,15 +614,15 @@ c          output web data
      *   '(i4,1pE11.3, 0p,i3, f8.4, 1pE11.3,0p, 4i4, 1p,8g11.3)')
      *   EventNo, E0, NN, cosz, firstcdepth, nrbin, nfai, ansites,
      *   NoOfSites, KEminObs   ! this is not exist in the older version          
-c                                                                      
-c           dE/dx lateral                                              
+!                                                                      
+!           dE/dx lateral                                              
          do i = 1, NoOfSites
             do k = 1, nfai
                write(fnoN, '("dE/dx",f7.1, 3i4)' )
      *            DepthList(i)*0.1, i, i, k
                write(fnoN, '(1p10E11.3)')
      *             ( dErfai(m,k,i), m=1,nrbin  ), dECent(i)
-c                                same  center value is put for all fai
+!                                same  center value is put for all fai
             enddo
          enddo
          close(fnoN)
