@@ -1,7 +1,7 @@
       block data cblkEvhnp
 
 #include  "Zevhnp.h"
-c            currently usable models
+!            currently usable models
       data RegMdls/'phits', 'jam', 'dpmjet3', 'fritiof7.02',
      *     'fritiof1.6', 'epos','sibyll',
      *     'gheisha', 'nucrin', 'ad-hoc', 'incdpm3', 'qgsjet2'/
@@ -13,16 +13,17 @@ c            currently usable models
      * DoNPadjust /0/ ,
      * dpmRareDecay /1/ ,
      * Mudirp /1.d0/ , 
+     * K0sSemiLD /12/ ,
      * Kpilog /0.0062/ ,
      * Kpicns /0.077/ ,
 #ifdef NEXT486
      * Elund /4.99/ , 
-     * Elund2 /4.99/,
-     * Elund3 /4.99/,
+     * Elund2 /4.99/ ,
+     * Elund3 /4.99/ ,
 #else
      * Elund /500./ , 
-     * Elund2 /500./,
-     * Elund3 /500./,
+     * Elund2 /500./ ,
+     * Elund3 /500./ ,
 #endif
      * SucPw /1.5/,
      * MulLow /1/,      ! old one is 0. bef. v.5.0
