@@ -1,6 +1,6 @@
-c     *******************
+!     *******************
       block data cblkObs
-c     *******************
+!     *******************
       implicit none
 #include  "Zobs.h"
 #include  "Zobsp.h"
