@@ -1,6 +1,6 @@
-c     *************************
+!     *************************
       block data  cblkTracking
-c     *************************
+!     *************************
       implicit none
 
 #include  "Ztrackp.h"
