@@ -1,24 +1,24 @@
       integer MaxIntMdls
       parameter(MaxIntMdls=8) 
-c                    variables in Event generator
-        record /ptcl/ Pjlab,     ! projectile in lab.
+!                    variables in Event generator
+        type(ptcl):: Pjlab,     ! projectile in lab.
      *                Pjtatr,    ! projectile in target at rest system
      *                Pjcms,     ! projectile in cms
      *                Rpjlab,    ! recoiled proj. in lab
      *                Rpjtatr,   ! recoiled proj. in target at rest system
      *                Rpjcms     ! recoiled proj. in cms
-c
-        record /ptcl/ Tglab,     ! target in lab.
+!
+        type(ptcl):: Tglab,     ! target in lab.
      *                Tgpatr,    ! target in projectile at rest system
      *                Tgcms,     ! target  in cms
      *                Rtglab,    ! recoiled target in lab
      *                Rtgpatr,   ! recoiled target in proj. at rest system
      *                Rtgcms     ! recoiled target in cms
-c
-        record /ptcl/ Cmsp,      ! cms particle formed by proj. and targe 
-c                                  in lab.
+!
+        type(ptcl):: Cmsp,      ! cms particle formed by proj. and targe 
+!                                  in lab.
      *                Missingp   ! missing mass particle (rest of
-c                                  two recoiled leadings) in cms.
+!                                  two recoiled leadings) in cms.
         real*8  Efrs,      ! effective roots 
      *          Powerexp,  ! pw2 in x**pw2 exp(-x)dx exp. type Pt distri.
      *          Powerp,    ! pw in x/(x +p0)**pw dx power type Pt distri.
@@ -31,7 +31,7 @@ c                                  two recoiled leadings) in cms.
         real*8  InteErg2(MaxIntMdls) ! energy bound for XsecModel
         character*16 ModelList2(MaxIntMdls) ! and corresponding model name
 
-c                             
+!                             
         character*16 ActiveMdl  ! interaction model to be applied to the
         integer::ActiveMdlNo    ! ActiveMdel index
         character*16 ActiveMdl2  ! interaction model to be applied to the
