@@ -1,5 +1,5 @@
 
-c               mass (GeV)
+!               mass (GeV)
 
        real*8
      1  masele, maspic, maspi0, maskc, mask0, masd,
@@ -19,4 +19,4 @@ c               mass (GeV)
      1 massigmap = 1.189, massigma0 = 1.192, massigmam=1.197,
      2 masgzai0 = 1.314, masgzaim = 1.321, 
      3 maslambda = 1.115, maslambdac = 2.282, masbomega=1.672)
-c        masddb and masnnb are the minimum value.
+!        masddb and masnnb are the minimum value.
