@@ -1,11 +1,11 @@
-c           This namelist data is frequently used.
-c           Some of them should be given mandatory.
+!           This namelist data is frequently used.
+!           Some of them should be given mandatory.
 
         namelist /Param/
      +  ASDepthList, ASHeightList, Azimuth, BaseTime, Cont, ContFile
      +, CosZenith, CutOffFile, Ddelta, DeadLine, DepthList, DestEventNo
      +, DtGMT, Freec, Generate, HeightList, HeightOfInj, Hidden
-     +, IncMuonPolari, InitRN, IntModel 
+     +, IncMuonPolari, InitRN, IntModel, MCSmodel
      +, Job, KEminObs, LatitOfSite
      +, LongitOfSite, LpmEffect, MinPhotoProdE, ObsPlane, OneDim
      +, PhotoProd, PrimaryFile, SeedFile, SkeletonFile, SourceDec
